# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

en_biyografiler = [
    "You can observe a lot just by watching.",
    "A house divided against itself cannot stand.",
    "Difficulties increase the nearer we get to the goal.",
    "Fate is in your hands and no one elses",
    "Be the chief but never the lord.",
    "Nothing happens unless first we dream.",
    "Well begun is half done.",
    "Life is a learning experience, only if you learn.",
    "Self-complacency is fatal to progress.",
    "Peace comes from within. Do not seek it without.",
    "What you give is what you get.",
    "We can only learn to love by loving.",
    "Life is change. Growth is optional. Choose wisely.",
    "You'll see it when you believe it.",
    "Today is the tomorrow we worried about yesterday.",
    "It's easier to see the mistakes on someone else's paper.",
    "Every man dies. Not every man really lives.",
    "To lead people walk behind them.",
    "Having nothing, nothing can he lose.",
    "Trouble is only opportunity in work clothes.",
    "A rolling stone gathers no moss.",
    "Ideas are the beginning points of all fortunes.",
    "Everything in life is luck.",
    "Doing nothing is better than being busy doing nothing.",
    "Trust yourself. You know more than you think you do.",
    "Study the past, if you would divine the future.",
    "The day is already blessed, find peace within it.",
    "From error to error one discovers the entire truth.",
    "Well done is better than well said.",
    "Bite off more than you can chew, then chew it.",
    "Work out your own salvation. Do not depend on others.",
    "One today is worth two tomorrows.",
    "Once you choose hope, anythings possible.",
    "God always takes the simplest way.",
    "One fails forward toward success.",
    "From small beginnings come great things.",
    "Learning is a treasure that will follow its owner everywhere",
    "Be as you wish to seem.",
    "The world is always in movement.",
    "Never mistake activity for achievement.",
    "What worries you masters you.",
    "One faces the future with ones past.",
    "Goals are the fuel in the furnace of achievement.",
    "Who sows virtue reaps honour.",
    "Be kind whenever possible. It is always possible.",
    "Talk doesn't cook rice.",
    "He is able who thinks he is able.",
    "Be as you wish to seem.",
    "A goal without a plan is just a wish.",
    "To succeed, we must first believe that we can.",
    "Learn from yesterday, live for today, hope for tomorrow.",
    "A weed is no more than a flower in disguise.",
    "Do, or do not. There is no try.",
    "All serious daring starts from within.",
    "The best teacher is experience learned from failures.",
    "Think how hard physics would be if particles could think.",
    "Love is the flower you've got to let grow.",
    "Don't wait. The time will never be just right.",
    "One fails forward toward success.",
    "Time is the wisest counsellor of all.",
    "You give before you get.",
    "Wisdom begins in wonder.",
    "Without courage, wisdom bears no fruit.",
    "Change in all things is sweet.",
    "What you fear is that which requires action to overcome.",
    "The best teacher is experience learned from failures.",
    "When performance exceeds ambition, the overlap is called success.",
    "When deeds speak, words are nothing.",
    "Real magic in relationships means an absence of judgement of others.",
    "When performance exceeds ambition, the overlap is called success.",
    "I never think of the future. It comes soon enough.",
    "Skill to do comes of doing.",
    "Wisdom is the supreme part of happiness.",
    "I believe that every person is born with talent.",
    "Important principles may, and must, be inflexible.",
    "The undertaking of a new action brings new strength.",
    "I believe that every person is born with talent.",
    "The years teach much which the days never know.",
    "Our distrust is very expensive.",
    "All know the way; few actually walk it.",
    "Great talent finds happiness in execution.",
    "Faith in oneself is the best and safest course.",
    "Courage is going from failure to failure without losing enthusiasm.",
    "The two most powerful warriors are patience and time.",
    "Anticipate the difficult by managing the easy.",
    "Those who are free of resentful thoughts surely find peace.",
    "Talk doesn't cook rice.",
    "A short saying often contains much wisdom.",
    "The day is already blessed, find peace within it.",
    "It takes both sunshine and rain to make a rainbow.",
    "A beautiful thing is never perfect.",
    "Only do what your heart tells you.",
    "Life is movement-we breathe, we eat, we walk, we move!",
    "No one can make you feel inferior without your consent.",
    "One fails forward toward success.",
    "Argue for your limitations, and sure enough theyre yours.",
    "Luck is what happens when preparation meets opportunity.",
    "Victory belongs to the most persevering.",
    "Once you choose hope, anythings possible.",
    "Love all, trust a few, do wrong to none.",
    "In order to win, you must expect to win.",
    "A goal is a dream with a deadline.",
    "You can do it if you believe you can!",
    "Set your goals high, and don't stop till you get there.",
    "Every new day is another chance to change your life.",
    "Smile, breathe, and go slowly.",
    "Nobody will believe in you unless you believe in yourself.",
    "Be kind whenever possible. It is always possible.",
    "Do more than dream: work.",
    "No man was ever wise by chance.",
    "Some pursue happiness, others create it.",
    "It's easier to see the mistakes on someone else's paper.",
    "Think how hard physics would be if particles could think.",
    "Well begun is half done.",
    "He that is giddy thinks the world turns round.",
    "Don't ruin the present with the ruined past.",
    "Do something wonderful, people may imitate it.",
    "We do what we do because we believe.",
    "Great talent finds happiness in execution.",
    "Do one thing every day that scares you.",
    "If you cannot be silent be brilliant and thoughtful.",
    "Smile, breathe, and go slowly.",
    "Who looks outside, dreams; who looks inside, awakes.",
    "What we think, we become.",
    "The shortest answer is doing.",
    "All our knowledge has its origins in our perceptions.",
    "He is able who thinks he is able.",
    "The harder you fall, the higher you bounce.",
    "Trusting our intuition often saves us from disaster.",
    "Truth is powerful and it prevails.",
    "Talk doesn't cook rice.",
    "Light tomorrow with today!",
    "Silence is a fence around wisdom.",
    "Society develops wit, but its contemplation alone forms genius.",
    "Real magic in relationships means an absence of judgement of others.",
    "The years teach much which the days never know.",
    "We can only learn to love by loving.",
    "The simplest things are often the truest.",
    "What you give is what you get.",
    "Everyone smiles in the same language.",
    "A short saying often contains much wisdom.",
    "Yesterday I dared to struggle. Today I dare to win.",
    "Victory belongs to the most persevering.",
    "No alibi will save you from accepting the responsibility.",
    "If you can dream it, you can do it.",
    "From error to error one discovers the entire truth.",
    "It is better to travel well than to arrive.",
    "Life shrinks or expands in proportion to one's courage.",
    "You have to believe in yourself.",
    "Our intention creates our reality.",
    "Silence is a true friend who never betrays.",
    "Character develops itself in the stream of life.",
    "From little acorns mighty oaks do grow.",
    "You have to believe in yourself.",
    "You can't stop the waves, but you can learn to surf.",
    "Reality does not conform to the ideal, but confirms it.",
    "Speak low, if you speak love.",
    "A really great talent finds its happiness in execution.",
    "Reality leaves a lot to the imagination.",
    "Our intention creates our reality.",
    "Society develops wit, but its contemplation alone forms genius.",
    "The greatest remedy for anger is delay.",
    "Growth itself contains the germ of happiness.",
    "You can do what's reasonable or you can decide what's possible.",
    "Nothing strengthens authority so much as silence.",
    "Wherever you go, go with all your heart.",
    "The only real valuable thing is intuition.",
    "I believe that every person is born with talent.",
    "Good luck is another name for tenacity of purpose.",
    "Rainbows apologize for angry skies.",
    "Friendship isn't a big thing. It's a million little things.",
    "Time is the most valuable thing a man can spend.",
    "Whatever happens, take responsibility.",
    "Experience is simply the name we give our mistakes.",
    "I think and that is all that I am.",
    "A good plan today is better than a perfect plan tomorrow.",
    "Be as you wish to seem.",
    "If the shoe doesn't fit, must we change the foot?",
    "Each day provides its own gifts.",
    "While we stop to think, we often miss our opportunity.",
    "Life isn't about finding yourself. Life is about creating yourself.",
    "To bring anything into your life, imagine that it's already there.",
    "Begin to weave and God will give you the thread.",
    "The more you know yourself, the more you forgive yourself.",
    "Without faith, nothing is possible. With it, nothing is impossible.",
    "What worries you masters you.",
    "Once we accept our limits, we go beyond them.",
    "Don't be pushed by your problems; be led by your dreams.",
    "Everything you can imagine is real.",
    "The shortest answer is doing.",
    "A beautiful thing is never perfect.",
    "Fear is a darkroom where negatives develop.",
    "The simplest things are often the truest.",
    "The truest wisdom is a resolute determination.",
    "Life is the flower for which love is the honey.",
    "Freedom is the right to live as we wish.",
    "Change your thoughts, change your life!",
    "Never ignore a gut feeling, but never believe that it's enough.",
    "Loss is nothing else but change,and change is Natures delight.",
    "Someone is special only if you tell them.",
    "Great talent finds happiness in execution.",
    "Today is the tomorrow you worried about yesterday.",
    "There is no way to happiness, happiness is the way.",
    "The day always looks brighter from behind a smile.",
    "A beautiful thing is never perfect.",
    "No alibi will save you from accepting the responsibility.",
    "Argue for your limitations, and sure enough theyre yours.",
    "You can observe a lot just by watching.",
    "Reality leaves a lot to the imagination.",
    "A stumble may prevent a fall.",
    "He who talks more is sooner exhausted.",
    "Well begun is half done.",
    "He who is contented is rich.",
    "Work out your own salvation. Do not depend on others.",
    "You can do it if you believe you can!",
    "What we achieve inwardly will change outer reality.",
    "Our strength grows out of our weaknesses.",
    "We must become the change we want to see.",
    "Happiness is found in doing, not merely possessing.",
    "Put your future in good hands � your own.",
    "We choose our destiny in the way we treat others.",
    "Time is the most valuable thing a man can spend.",
    "No snowflake in an avalanche ever feels responsible.",
    "Smile, breathe, and go slowly.",
    "Fortune favours the brave.",
    "I believe in one thing only, the power of human will.",
    "The more you know yourself, the more you forgive yourself.",
    "The best way out is always through.",
    "The mind unlearns with difficulty what it has long learned.",
    "I destroy my enemies when I make them my friends.",
    "No garden is without its weeds.",
    "There is no failure except in no longer trying.",
    "Kind words will unlock an iron door.",
    "Problems are only opportunities with thorns on them.",
    "Life is just a chance to grow a soul.",
    "Reality does not conform to the ideal, but confirms it.",
    "If you can dream it, you can do it.",
    "Mountains cannot be surmounted except by winding paths.",
    "May our hearts garden of awakening bloom with hundreds of flowers.",
    "Nobody will believe in you unless you believe in yourself.",
    "Fortune befriends the bold.",
    "Keep true to the dreams of thy youth.",
    "You're never a loser until you quit trying.",
    "Science is organized knowledge. Wisdom is organized life.",
    "Knowing is not enough; we must apply!",
    "Strong beliefs win strong men, and then make them stronger.",
    "Autumn is a second spring when every leaf is a flower.",
    "If you surrender to the wind, you can ride it.",
    "Character develops itself in the stream of life.",
    "We must become the change we want to see.",
    "Keep yourself to the sunshine and you cannot see the shadow.",
    "Write your plans in pencil and give God the eraser.",
    "Inspiration exists, but it has to find us working.",
    "All serious daring starts from within.",
    "Pick battles big enough to matter, small enough to win.",
    "Don't compromise yourself. You are all you've got.",
    "He that is giddy thinks the world turns round.",
    "A short saying oft contains much wisdom.",
    "Difficulties are things that show a person what they are.",
    "When you doubt your power, you give power to your doubt.",
    "The cause is hidden. The effect is visible to all.",
    "A weed is no more than a flower in disguise.",
    "Keep true to the dreams of thy youth.",
    "A prudent question is one half of wisdom.",
    "The path to success is to take massive, determined action.",
    "I allow my intuition to lead my path.",
    "Nature takes away any faculty that is not used.",
    "All our knowledge has its origins in our perceptions.",
    "If the shoe doesn't fit, must we change the foot?",
    "Life shrinks or expands in proportion to one's courage.",
    "May our hearts garden of awakening bloom with hundreds of flowers.",
    "If you wish to be a writer, write.",
    "Today is the tomorrow we worried about yesterday.",
    "There is no way to prosperity, prosperity is the way.",
    "Talk doesn't cook rice.",
    "Wherever you go, go with all your heart.",
    "Either you run the day or the day runs you.",
    "Write your plans in pencil and give God the eraser.",
    "Better be ignorant of a matter than half know it.",
    "Follow your instincts. That is where true wisdom manifests itself.",
    "There never was a good knife made of bad steel.",
    "To accomplish great things, we must dream as well as act.",
    "Patience is the companion of wisdom.",
    "The mind is everything. What you think you become.",
    "To enjoy life, we must touch much of it lightly.",
    "To fly, we have to have resistance.",
    "The more you know yourself, the more you forgive yourself.",
    "What you see depends on what you're looking for.",
    "The heart has its reasons which reason knows not of.",
    "When you doubt your power, you give power to your doubt.",
    "Be great in act, as you have been in thought.",
    "Imagination rules the world.",
    "Kind words do not cost much. Yet they accomplish much.",
    "Wherever you go, go with all your heart.",
    "In order to win, you must expect to win.",
    "You're never a loser until you quit trying.",
    "There is no greater harm than that of time wasted.",
    "Intuition will tell the thinking mind where to look next.",
    "Nature takes away any faculty that is not used.",
    "Doing nothing is better than being busy doing nothing.",
    "It is better to travel well than to arrive.",
    "Once you choose hope, anythings possible.",
    "Worry gives a small thing a big shadow.",
    "Do, or do not. There is no try.",
    "Fears are nothing more than a state of mind.",
    "Mountains cannot be surmounted except by winding paths.",
    "May our hearts garden of awakening bloom with hundreds of flowers.",
    "The journey of a thousand miles begins with one step.",
    "Don't be pushed by your problems; be led by your dreams.",
    "The greatest remedy for anger is delay.",
    "Worry gives a small thing a big shadow.",
    "Blaze with the fire that is never extinguished.",
    "Don't cry because it's over. Smile because it happened.",
    "Time is the wisest counsellor of all.",
    "No is easier to do. Yes is easier to say.",
    "From little acorns mighty oaks do grow.",
    "To be wrong is nothing unless you continue to remember it.",
    "Write your plans in pencil and give God the eraser.",
    "Once we accept our limits, we go beyond them.",
    "He who talks more is sooner exhausted.",
    "I never think of the future. It comes soon enough.",
    "Whatever happens, take responsibility.",
    "Yesterdays home runs don't win today's games.",
    "The world is always in movement.",
    "Inspiration exists, but it has to find us working.",
    "Silence is deep as Eternity, Speech is shallow as Time.",
    "Don't smother each other. No one can grow in the shade.",
    "We must become the change we want to see.",
    "An ant on the move does more than a dozing ox",
    "You can't shake hands with a clenched fist.",
    "A good decision is based on knowledge and not on numbers.",
    "Once we accept our limits, we go beyond them.",
    "The cautious seldom err.",
    "Ideas are the beginning points of all fortunes.",
    "Every man dies. Not every man really lives.",
    "If there is no struggle, there is no progress.",
    "There is no way to prosperity, prosperity is the way.",
    "Where there is great love, there are always miracles.",
    "Trusting our intuition often saves us from disaster.",
    "Friendship isn't a big thing. It's a million little things.",
    "Goals are the fuel in the furnace of achievement.",
    "Each day provides its own gifts.",
    "Time you enjoy wasting, was not wasted.",
    "Every problem has a gift for you in its hands.",
    "Sadness flies away on the wings of time.",
    "The only real valuable thing is intuition.",
    "Fortune befriends the bold.",
    "I have often regretted my speech, never my silence.",
    "May our hearts garden of awakening bloom with hundreds of flowers.",
    "I destroy my enemies when I make them my friends.",
    "Sadness flies away on the wings of time.",
    "Never put off till tomorrow what you can do today.",
    "Minds are like parachutes. They only function when open.",
    "If a man does his best, what else is there?",
    "The secret of success is constancy to purpose.",
    "Imagination rules the world.",
    "Well begun is half done.",
    "The best way out is always through.",
    "Without faith, nothing is possible. With it, nothing is impossible.",
    "Life is a progress, and not a station.",
    "All seasons are beautiful for the person who carries happiness within.",
    "To avoid criticism, do nothing, say nothing, be nothing.",
    "Whatever happens, take responsibility.",
    "All things change; nothing perishes.",
    "No one can make you feel inferior without your consent.",
    "Absence makes the heart grow fonder.",
    "Imagination is the highest kite one can fly.",
    "Don't be pushed by your problems; be led by your dreams.",
    "Nothing happens unless first we dream.",
    "Minds are like parachutes. They only function when open.",
    "The winds and waves are always on the side of the ablest navigators.",
    "The future belongs to those who believe in the beauty of their dreams.",
    "The winds and waves are always on the side of the ablest navigators.",
    "I never see what has been done; I only see what remains to be done.",
    "Begin at once to live and count each separate day as a separate life.",
    "The bird of paradise alights only upon the hand that does not grasp.",
    "Think as a wise man but communicate in the language of the people.",
    "If one does not know to which port is sailing, no wind is favorable.",
    "To be upset over what you don't have is to waste what you do have.",
    "If we did the things we are capable of, we would astound ourselves.",
    "Nothing in life is to be feared. It is only to be understood.",
    "Life is a process. We are a process. The universe is a process.",
    "We learn what we have said from those who listen to our speaking.",
    "If you get up one more time than you fall, you will make it through.",
    "The doors we open and close each day decide the lives we live.",
    "Begin at once to live and count each separate day as a separate life.",
    "What you do not want done to yourself, do not do to others.",
    "Short words are best and the old words when short are best of all.",
    "If you light a lamp for somebody, it will also brighten your path.",
    "Love is just a word until someone comes along and gives it meaning.",
    "The secret to a rich life is to have more beginnings than endings.",
    "Nothing in life is to be feared. It is only to be understood.",
    "The world is a book, and those who do not travel read only a page.",
    "I'm not afraid of storms, for Im learning how to sail my ship.",
    "Think for yourselves and let others enjoy the privilege to do so too.",
    "How we spend our days is, of course, how we spend our lives.",
    "It has never been my object to record my dreams, just to realize them.",
    "The doors we open and close each day decide the lives we live.",
    "Better to have loved and lost, than to have never loved at all.",
    "The best way to pay for a lovely moment is to enjoy it.",
    "I always wanted to be somebody, but I should have been more specific.",
    "Yeah we all shine on, like the moon, and the stars, and the sun.",
    "What you do not want done to yourself, do not do to others.",
    "If you correct your mind, the rest of your life will fall into place.",
    "The world makes way for the man who knows where he is going.",
    "I cannot make my days longer so I strive to make them better.",
    "Think for yourselves and let others enjoy the privilege to do so too.",
    "Tension is who you think you should be. Relaxation is who you are.",
    "We cannot do everything at once, but we can do something at once.",
    "It is fatal to enter any war without the will to win it.",
    "The way is not in the sky. The way is in the heart.",
    "Most people are about as happy as they make up their minds to be",
    "Three things cannot be long hidden: the sun, the moon, and the truth.",
    "We learn what we have said from those who listen to our speaking.",
    "The way is not in the sky. The way is in the heart.",
    "Don't be afraid to go out on a limb. That's where the fruit is.",
    "No man can succeed in a line of endeavor which he does not like.",
    "Think for yourselves and let others enjoy the privilege to do so too.",
    "The future belongs to those who believe in the beauty of their dreams.",
    "The winds and waves are always on the side of the ablest navigators.",
    "If you light a lamp for somebody, it will also brighten your path.",
    "Shoot for the moon. Even if you miss, you'll land among the stars.",
    "I'm not afraid of storms, for Im learning how to sail my ship.",
    "It does not matter how slowly you go as long as you do not stop.",
    "Every day may not be good, but there's something good in every day.",
    "Most folks are about as happy as they make up their minds to be.",
    "Life is a succession of lessons, which must be lived to be understood.",
    "Love is just a word until someone comes along and gives it meaning.",
    "It is fatal to enter any war without the will to win it.",
    "If you cannot do great things, do small things in a great way.",
    "The free man is he who does not fear to go to the end of his thought.",
    "If it is not right do not do it; if it is not true do not say it.",
    "Fear is a darkroom where negatives develop.",
    "It is in your moments of decision that your destiny is shaped.",
    "Those who are free of resentful thoughts surely find peace.",
    "Blaze with the fire that is never extinguished.",
    "An obstacle may be either a stepping stone or a stumbling block.",
    "The pain passes, but the beauty remains.",
    "All I can say about life is, Oh God, enjoy it!",
    "You won't skid if you stay in a rut.",
    "Happiness depends upon ourselves.",
    "Tension is who you think you should be. Relaxation is who you are.",
    "Wherever a man turns he can find someone who needs him.",
    "The years teach much which the days never know.",
    "Never idealize others. They will never live up to your expectations.",
    "He who is contented is rich.",
    "No man was ever wise by chance.",
    "The more you know yourself, the more you forgive yourself.",
    "Trust yourself. You know more than you think you do.",
    "Time you enjoy wasting, was not wasted.",
    "Happiness is not something ready made. It comes from your own actions.",
    "Meaning is not what you start with but what you end up with.",
    "No one has ever become poor by giving.",
    "What you do not want done to yourself, do not do to others.",
    "All is flux; nothing stays still.",
    "He who is fixed to a star does not change his mind.",
    "When the solution is simple, God is answering.",
    "All achievements, all earned riches, have their beginning in an idea.",
    "Do not turn back when you are just at the goal.",
    "You can't trust without risk but neither can you live in a cocoon.",
    "Error is discipline through which we advance.",
    "The truth is always exciting. Speak it, then. Life is dull without it.",
    "What worries you masters you.",
    "The superior man is modest in his speech, but exceeds in his actions.",
    "Those who will play with cats must expect to be scratched.",
    "I've never seen a smiling face that was not beautiful.",
    "In all things of nature there is something of the marvellous.",
    "Life isn't about finding yourself. Life is about creating yourself.",
    "The universe is transformation; our life is what our thoughts make it.",
    "Memory is the mother of all wisdom.",
    "Silence is the true friend that never betrays.",
    "Watch the little things; a small leak will sink a great ship.",
    "God has given you one face, and you make yourself another.",
    "The more you know yourself, the more you forgive yourself.",
    "To be wronged is nothing unless you continue to remember it.",
    "Kindness is the greatest wisdom.",
    "Action will remove the doubts that theory cannot solve.",
    "Your big opportunity may be right where you are now.",
    "Kindness is the greatest wisdom.",
    "The day you decide to do it is your lucky day.",
    "We must not say every mistake is a foolish one.",
    "Imagination is the highest kite one can fly.",
    "Accept challenges, so that you may feel the exhilaration of victory.",
    "It is better to understand a little than to misunderstand a lot.",
    "You don't drown by falling in water. You drown by staying there.",
    "Correction does much, but encouragement does more.",
    "Know, first, who you are, and then adorn yourself accordingly.",
    "The pain passes, but the beauty remains.",
    "The cause is hidden. The effect is visible to all.",
    "Time you enjoy wasting, was not wasted.",
    "Happiness is not something ready made. It comes from your own actions.",
    "Life is 10% what happens to you and 90% how you react to it.",
    "An obstacle may be either a stepping stone or a stumbling block.",
    "To want to be what one can be is purpose in life.",
    "The future belongs to those who believe in the beauty of their dreams.",
    "Truth is powerful and it prevails.",
    "History will be kind to me for I intend to write it.",
    "Short words are best and the old words when short are best of all.",
    "Our lives are a sum total of the choices we have made.",
    "Time stays long enough for anyone who will use it.",
    "Each day provides its own gifts.",
    "If you light a lamp for somebody, it will also brighten your path.",
    "You must welcome change as the rule but not as your ruler.",
    "Always be smarter than the people who hire you.",
    "We do what we do because we believe.",
    "Formula for success: under promise and over deliver.",
    "The eye sees only what the mind is prepared to comprehend.",
    "You can't stop the waves, but you can learn to surf.",
    "People seldom notice old clothes if you wear a big smile.",
    "Nothing diminishes anxiety faster than action.",
    "Never mistake activity for achievement.",
    "Fortune favours the brave.",
    "Can you imagine what I would do if I could do all I can?",
    "Ignorance never settle a question.",
    "The awareness of our own strength makes us modest.",
    "The journey of a thousand miles begins with one step.",
    "They must often change, who would be constant in happiness or wisdom.",
    "There are no failures. Just experiences and your reactions to them.",
    "Your future depends on many things, but mostly on you.",
    "If you surrender to the wind, you can ride it.",
    "It is better to understand a little than to misunderstand a lot.",
    "If we did the things we are capable of, we would astound ourselves.",
    "We must not say every mistake is a foolish one.",
    "The superior man is modest in his speech, but exceeds in his actions.",
    "As long as your going to be thinking anyway, think big.",
    "Without some goals and some efforts to reach it, no man can live.",
    "He who obtains has little. He who scatters has much.",
    "Wherever a man turns he can find someone who needs him.",
    "Myths which are believed in tend to become true.",
    "If the shoe doesn't fit, must we change the foot?",
    "Love all, trust a few, do wrong to none.",
    "Those who will play with cats must expect to be scratched.",
    "To be upset over what you don't have is to waste what you do have.",
    "The foot feels the foot when it feels the ground.",
    "Not what we have but what we enjoy constitutes our abundance.",
    "It is never too late to be what you might have been.",
    "The beginning is always today.",
    "Sadness flies away on the wings of time.",
    "Self-trust is the first secret of success.",
    "Without some goals and some efforts to reach it, no man can live.",
    "Don't look back. Something might be gaining on you.",
    "From error to error one discovers the entire truth.",
    "They must often change, who would be constant in happiness or wisdom.",
    "If it is not right do not do it; if it is not true do not say it.",
    "A man should look for what is, and not for what he thinks should be.",
    "He who conquers others is strong; He who conquers himself is mighty.",
    "Smile, breathe, and go slowly.",
    "Nothing diminishes anxiety faster than action.",
    "The secret of success is constancy to purpose.",
    "Anything you really want, you can attain, if you really go after it.",
    "Arriving at one point is the starting point to another.",
    "Don't be afraid to go out on a limb. That's where the fruit is.",
    "When the solution is simple, God is answering.",
    "Never put off till tomorrow what you can do today.",
    "It is in your moments of decision that your destiny is shaped.",
    "It is only possible to live happily ever after on a day to day basis.",
    "One fails forward toward success.",
    "A man sees in the world what he carries in his heart.",
    "If you surrender to the wind, you can ride it.",
    "Love is the flower you've got to let grow.",
    "Sooner or later, those who win are those who think they can.",
    "The only limit to your impact is your imagination and commitment.",
    "Silence is the true friend that never betrays.",
    "You are special, you are unique, you are the best!",
    "It is in your moments of decision that your destiny is shaped.",
    "Life is a learning experience, only if you learn.",
    "A short saying oft contains much wisdom.",
    "I'm not afraid of storms, for Im learning how to sail my ship.",
    "To know oneself is to study oneself in action with another person.",
    "We must not allow ourselves to become like the system we oppose.",
    "Smile, breathe and go slowly.",
    "The day you decide to do it is your lucky day.",
    "To want to be what one can be is purpose in life.",
    "Reality is merely an illusion, albeit a very persistent one.",
    "When you come to the end of your rope, tie a knot and hang on.",
    "Always be mindful of the kindness and not the faults of others.",
    "When fate hands us a lemon, lets try to make lemonade.",
    "A man is great by deeds, not by birth.",
    "Success is getting what you want. Happiness is wanting what you get.",
    "I believe that every person is born with talent.",
    "Put your future in good hands � your own.",
    "Don't be pushed by your problems; be led by your dreams.",
    "The cautious seldom err.",
    "No garden is without its weeds.",
    "Who looks outside, dreams; who looks inside, awakes.",
    "A good rest is half the work.",
    "Small opportunities are often the beginning of great enterprises.",
    "You can do what's reasonable or you can decide what's possible.",
    "To be tested is good. The challenged life may be the best therapist.",
    "There are no failures. Just experiences and your reactions to them.",
    "I destroy my enemies when I make them my friends.",
    "Do something wonderful, people may imitate it.",
    "Fears are nothing more than a state of mind.",
    "Take heed: you do not find what you do not seek.",
    "Be slow of tongue and quick of eye.",
    "Freedom is not worth having if it does not connote freedom to err.",
    "Nothing diminishes anxiety faster than action.",
    "He who obtains has little. He who scatters has much.",
    "I'm not afraid of storms, for Im learning how to sail my ship.",
    "Be great in act, as you have been in thought.",
    "The cause is hidden. The effect is visible to all.",
    "He who obtains has little. He who scatters has much.",
    "No day in which you learn something is a complete loss.",
    "When the solution is simple, God is answering.",
    "Real success is finding your lifework in the work that you love.",
    "Better than a thousand hollow words, is one word that brings peace.",
    "All the flowers of all the tomorrows are in the seeds of today.",
    "Some pursue happiness, others create it.",
    "Your sacred space is where you can find yourself again and again.",
    "There never was a good knife made of bad steel.",
    "He who talks more is sooner exhausted.",
    "As you think, so shall you become.",
    "Do not turn back when you are just at the goal.",
    "He who obtains has little. He who scatters has much.",
    "In seed time learn, in harvest teach, in winter enjoy.",
    "A short saying oft contains much wisdom.",
    "Every gift from a friend is a wish for your happiness.",
    "Go put your creed into the deed. Nor speak with double tongue.",
    "The wisest men follow their own direction.",
    "Hope arouses, as nothing else can arouse, a passion for the possible.",
    "Myths which are believed in tend to become true.",
    "Who sows virtue reaps honour.",
    "The future belongs to those who believe in the beauty of their dreams.",
    "Everything has beauty, but not everyone sees it.",
    "Courage is going from failure to failure without losing enthusiasm.",
    "He who talks more is sooner exhausted.",
    "Nothing ever goes away until it has taught us what we need to know.",
    "Smile, breathe, and go slowly.",
    "Small opportunities are often the beginning of great enterprises.",
    "When you learn, teach. When you get, give.",
    "We choose our destiny in the way we treat others.",
    "The universe is transformation; our life is what our thoughts make it.",
    "Difficulties increase the nearer we get to the goal.",
    "Smile, breathe, and go slowly.",
    "Science is organized knowledge. Wisdom is organized life.",
    "Only when we are no longer afraid do we begin to live.",
    "If you smile when no one else is around, you really mean it.",
    "Life is a process. We are a process. The universe is a process.",
    "Love is the only force capable of transforming an enemy into friend.",
    "Good luck is another name for tenacity of purpose.",
    "Well done is better than well said.",
    "Our lives are a sum total of the choices we have made.",
    "In all chaos there is a cosmos, in all disorder a secret order.",
    "A man is not where he lives but where he loves.",
    "You can do what's reasonable or you can decide what's possible.",
    "The greatest remedy for anger is delay.",
    "The price of greatness is responsibility.",
    "Decision is a risk rooted in the courage of being free.",
    "The day is already blessed, find peace within it.",
    "All things change; nothing perishes.",
    "You can do it if you believe you can!",
    "God has given you one face, and you make yourself another.",
    "The world doesn�t happen to you it happens from you.",
    "It is only possible to live happily ever after on a day to day basis.",
    "More powerful than the will to win is the courage to begin.",
    "Wisdom is the supreme part of happiness.",
    "Who looks outside, dreams; who looks inside, awakes.",
    "Learning is finding out what you already know.",
    "We learn what we have said from those who listen to our speaking.",
    "Saying thank you is more than good manners. It is good spirituality.",
    "Silence is a source of great strength.",
    "Joy is the best makeup.",
    "If you cannot be silent be brilliant and thoughtful.",
    "There is no great genius without some touch of madness.",
    "A jug fills drop by drop.",
    "You must welcome change as the rule but not as your ruler.",
    "Once you choose hope, anythings possible.",
    "Talk doesn't cook rice.",
    "The only real valuable thing is intuition.",
    "Accept challenges, so that you may feel the exhilaration of victory.",
    "We aim above the mark to hit the mark.",
    "Being angry never solves anything.",
    "Every problem has a gift for you in its hands.",
    "All men who have achieved great things have been great dreamers.",
    "Where all think alike, no one thinks very much.",
    "Everything that exists is in a manner the seed of that which will be.",
    "Be less curious about people and more curious about ideas.",
    "The heart has eyes which the brain knows nothing of.",
    "Don't be pushed by your problems; be led by your dreams.",
    "I'm not afraid of storms, for Im learning how to sail my ship.",
    "A short saying oft contains much wisdom.",
    "Think how hard physics would be if particles could think.",
    "Only those who dare to fail greatly can ever achieve greatly.",
    "Mistakes are always forgivable, if one has the courage to admit them.",
    "Go to your bosom: Knock there, and ask your heart what it doth know.",
    "If you do not change direction, you may end up where you are heading.",
    "What we see is mainly what we look for.",
    "If you correct your mind, the rest of your life will fall into place.",
    "Stay away from what might have been and look at what will be.",
    "When the solution is simple, God is answering.",
    "Act as if what you do makes a difference. It does.",
    "There never was a good knife made of bad steel.",
    "Better be ignorant of a matter than half know it.",
    "Most people are about as happy as they make up their minds to be",
    "Every new day is another chance to change your life.",
    "Do good by stealth, and blush to find it fame.",
    "When you doubt your power, you give power to your doubt.",
    "I always wanted to be somebody, but I should have been more specific.",
    "Pick battles big enough to matter, small enough to win.",
    "If we did the things we are capable of, we would astound ourselves.",
    "Don't talk about what you have done or what you are going to do.",
    "The way is not in the sky. The way is in the heart.",
    "Most powerful is he who has himself in his own power.",
    "Those who are free of resentful thoughts surely find peace.",
    "Experience can only be gained by doing not by thinking or dreaming.",
    "From wonder into wonder existence opens.",
    "An ant on the move does more than a dozing ox",
    "To avoid criticism, do nothing, say nothing, be nothing.",
    "He who fears being conquered is sure of defeat.",
    "Life is what happens while you are making other plans.",
    "Those who are free of resentful thoughts surely find peace.",
    "Good luck is another name for tenacity of purpose.",
    "Nothing diminishes anxiety faster than action.",
    "Kindness is the golden chain by which society is bound together.",
    "You need chaos in your soul to give birth to a dancing star.",
    "I have often regretted my speech, never my silence.",
    "It can't be spring if your heart is filled with past failures.",
    "If you cannot be silent be brilliant and thoughtful.",
    "If you wish to be a writer, write.",
    "No yesterdays are ever wasted for those who give themselves to today.",
    "The truth is always exciting. Speak it, then. Life is dull without it.",
    "There are no failures � just experiences and your reactions to them.",
    "Action is the foundational key to all success.",
    "Silence is a fence around wisdom.",
    "Think how hard physics would be if particles could think.",
    "We shall never know all the good that a simple smile can do.",
    "Nature takes away any faculty that is not used.",
    "Fears are nothing more than a state of mind.",
    "We must embrace pain and burn it as fuel for our journey.",
    "It has never been my object to record my dreams, just to realize them.",
    "Don't wait for people to be friendly. Show them how.",
    "Better to have loved and lost, than to have never loved at all.",
    "A man is not where he lives but where he loves.",
    "From error to error one discovers the entire truth.",
    "I believe that every person is born with talent.",
    "Three things cannot be long hidden: the sun, the moon, and the truth.",
    "Every day may not be good, but there's something good in every day.",
    "Well begun is half done.",
    "Do one thing every day that scares you.",
    "Whatever happens, take responsibility.",
    "No is easier to do. Yes is easier to say.",
    "Life is a process. We are a process. The universe is a process.",
    "Don't wait. The time will never be just right.",
    "Be as you wish to seem.",
    "Knowing is not enough; we must apply!",
    "Science is organized knowledge. Wisdom is organized life.",
    "The path to success is to take massive, determined action.",
    "Freedom is not worth having if it does not connote freedom to err.",
    "Each day can be one of triumph if you keep up your interests.",
    "Nature is a mutable cloud which is always and never the same.",
    "Life is what you make of it. Always has been, always will be.",
    "If you do not change direction, you may end up where you are heading.",
    "Worry often gives a small thing a big shadow.",
    "We know what we are, but know not what we may be.",
    "Do not turn back when you are just at the goal.",
    "Freedom is what you do with what's been done to you.",
    "Pick battles big enough to matter, small enough to win.",
    "It is never too late to be what you might have been.",
    "The truth which has made us free will in the end make us glad also.",
    "The heart has its reasons which reason knows not of.",
    "To succeed, we must first believe that we can.",
    "He who has imagination without learning has wings but no feet.",
    "Never ignore a gut feeling, but never believe that it's enough.",
    "Everything in life is luck.",
    "A goal without a plan is just a wish.",
    "Our lives are a sum total of the choices we have made.",
    "Watch the little things; a small leak will sink a great ship.",
    "When performance exceeds ambition, the overlap is called success.",
    "Work out your own salvation. Do not depend on others.",
    "Everyone smiles in the same language.",
    "We do what we do because we believe.",
    "Whoso loves, believes the impossible.",
    "Fate is in your hands and no one elses",
    "It isn't where you come from, it's where you're going that counts.",
    "Reality is merely an illusion, albeit a very persistent one.",
    "The greatest obstacle to connecting with our joy is resentment.",
    "Freedom is what you do with what's been done to you.",
    "Mountains cannot be surmounted except by winding paths.",
    "I believe that every person is born with talent.",
    "When anger use your energy to do something productive.",
    "Growth itself contains the germ of happiness.",
    "Victory belongs to the most persevering.",
    "We are all something, but none of us are everything.",
    "To want to be what one can be is purpose in life.",
    "Intuition will tell the thinking mind where to look next.",
    "Always be mindful of the kindness and not the faults of others.",
    "No yesterdays are ever wasted for those who give themselves to today.",
    "Do not turn back when you are just at the goal.",
    "Where all think alike, no one thinks very much.",
    "Action is the foundational key to all success.",
    "If you can't explain it simply, you don't understand it well enough.",
    "The truth which has made us free will in the end make us glad also.",
    "Sooner or later, those who win are those who think they can.",
    "He who lives in harmony with himself lives in harmony with the world.",
    "Begin at once to live and count each separate day as a separate life.",
    "He who knows himself is enlightened.",
    "Growth itself contains the germ of happiness.",
    "Kind words do not cost much. Yet they accomplish much.",
    "Think as a wise man but communicate in the language of the people.",
    "Kind words will unlock an iron door.",
    "Build a better mousetrap and the world will beat a path to your door.",
    "As our case is new, we must think and act anew.",
    "Fear is a darkroom where negatives develop.",
    "If you can't feed a hundred people, then feed just one.",
    "When anger use your energy to do something productive.",
    "From error to error one discovers the entire truth.",
    "The day you decide to do it is your lucky day.",
    "Happiness is not something ready made. It comes from your own actions.",
    "Don't let today's disappointments cast a shadow on tomorrow's dreams.",
    "Silence is a true friend who never betrays.",
    "As our case is new, we must think and act anew.",
    "Great talent finds happiness in execution.",
    "Keep yourself to the sunshine and you cannot see the shadow.",
    "Who sows virtue reaps honour.",
    "Goals are the fuel in the furnace of achievement.",
    "To be wronged is nothing unless you continue to remember it.",
    "You always succeed in producing a result.",
    "As we risk ourselves, we grow. Each new experience is a risk.",
    "What we achieve inwardly will change outer reality.",
    "Who we are never changes. Who we think we are does.",
    "If you correct your mind, the rest of your life will fall into place.",
    "If you do not change direction, you may end up where you are heading.",
    "An obstacle may be either a stepping stone or a stumbling block.",
    "A beautiful thing is never perfect.",
    "A man sees in the world what he carries in his heart.",
    "Never let lack of money interfere with having fun.",
    "Excellence is not a skill. It is an attitude.",
    "People may doubt what you say, but they will believe what you do.",
    "The most formidable weapon against errors of every kind is reason.",
    "If there is no struggle, there is no progress.",
    "No one can make you feel inferior without your consent.",
    "When you come to the end of your rope, tie a knot and hang on.",
    "Sooner or later, those who win are those who think they can.",
    "You only lose what you cling to.",
    "Life is a succession of moments. To live each one is to succeed.",
    "I know but one freedom and that is the freedom of the mind.",
    "Freedom is not worth having if it does not connote freedom to err.",
    "In the middle of every difficulty lies opportunity.",
    "Trust yourself. You know more than you think you do.",
    "If one does not know to which port is sailing, no wind is favorable.",
    "Wherever you go, go with all your heart.",
    "Every human being is the author of his own health or disease.",
    "When in doubt, tell the truth.",
    "To be wronged is nothing unless you continue to remember it.",
    "The path to success is to take massive, determined action.",
    "The ladder of success is never crowded at the top.",
    "Formula for success: under promise and over deliver.",
    "What you fear is that which requires action to overcome.",
    "Worry often gives a small thing a big shadow.",
    "He who has health has hope, and he who has hope has everything.",
    "All great achievements require time.",
    "The heart has eyes which the brain knows nothing of.",
    "A really great talent finds its happiness in execution.",
    "Impossibilities are merely things which we have not yet learned.",
    "Love all, trust a few, do wrong to none.",
    "Today is the tomorrow you worried about yesterday.",
    "Without faith, nothing is possible. With it, nothing is impossible.",
    "To be wrong is nothing unless you continue to remember it.",
    "Happiness is not something ready made. It comes from your own actions.",
    "A rolling stone gathers no moss.",
    "Trust yourself. You know more than you think you do.",
    "He who angers you conquers you.",
    "I never worry about action, but only inaction.",
    "The world makes way for the man who knows where he is going.",
    "No man is free who is not master of himself.",
    "He who conquers others is strong; He who conquers himself is mighty.",
    "The truest wisdom is a resolute determination.",
    "Those that know, do. Those that understand, teach.",
    "Do good by stealth, and blush to find it fame.",
    "An ant on the move does more than a dozing ox",
    "No act of kindness, no matter how small, is ever wasted.",
    "Every man is a volume if you know how to read him.",
    "The difficulties of life are intended to make us better, not bitter.",
    "A good rest is half the work.",
    "We choose our destiny in the way we treat others.",
    "Better be ignorant of a matter than half know it.",
    "You can't stop the waves, but you can learn to surf.",
    "Quality means doing it right when no one is looking.",
    "The cautious seldom err.",
    "Change your words. Change your world.",
    "Worry often gives a small thing a big shadow.",
    "The superior man is modest in his speech, but exceeds in his actions.",
    "All is flux; nothing stays still.",
    "I know but one freedom and that is the freedom of the mind.",
    "Every day may not be good, but there's something good in every day.",
    "A short saying often contains much wisdom.",
    "Great acts are made up of small deeds.",
    "The foot feels the foot when it feels the ground.",
    "The odds of hitting your target go up dramatically when you aim at it.",
    "It is in your moments of decision that your destiny is shaped.",
    "Open minds lead to open doors.",
    "They can do all because they think they can.",
    "Life is the flower for which love is the honey.",
    "The secret of success is constancy to purpose.",
    "Courage is going from failure to failure without losing enthusiasm.",
    "The secret of success is constancy to purpose.",
    "You have to think anyway, so why not think big?",
    "The world is a book, and those who do not travel read only a page.",
    "Smile, breathe and go slowly.",
    "If one does not know to which port is sailing, no wind is favorable.",
    "It is better to understand a little than to misunderstand a lot.",
    "Once you choose hope, anythings possible.",
    "To enjoy life, we must touch much of it lightly.",
    "Nothing strengthens authority so much as silence.",
    "Most folks are about as happy as they make up their minds to be.",
    "You can do what's reasonable or you can decide what's possible.",
    "Nobody will believe in you unless you believe in yourself.",
    "The one who always loses, is the only person who gets the reward.",
    "Better be ignorant of a matter than half know it.",
    "Character develops itself in the stream of life.",
    "All the flowers of all the tomorrows are in the seeds of today.",
    "Self-complacency is fatal to progress.",
    "Our intention creates our reality.",
    "From wonder into wonder existence opens.",
    "Happiness is found in doing, not merely possessing.",
    "The future is completely open, and we are writing it moment to moment.",
    "Smile, breathe, and go slowly.",
    "I cannot make my days longer so I strive to make them better.",
    "No is easier to do. Yes is easier to say.",
    "Nothing happens unless first we dream.",
    "There is no way to prosperity, prosperity is the way.",
    "I know but one freedom and that is the freedom of the mind.",
    "Better to have loved and lost, than to have never loved at all.",
    "From error to error one discovers the entire truth.",
    "No man can succeed in a line of endeavor which he does not like.",
    "Experience is simply the name we give our mistakes.",
    "Better be ignorant of a matter than half know it.",
    "Nothing is at last sacred but the integrity of your own mind.",
    "To bring anything into your life, imagine that it's already there.",
    "Light tomorrow with today!",
    "The undertaking of a new action brings new strength.",
    "Being angry never solves anything.",
    "Fortune favours the brave.",
    "What is not started today is never finished tomorrow.",
    "Light tomorrow with today!",
    "You can't stop the waves, but you can learn to surf.",
    "Nothing ever goes away until it has taught us what we need to know.",
    "Fate is in your hands and no one elses",
    "The ladder of success is never crowded at the top.",
    "It's easier to see the mistakes on someone else's paper.",
    "Chaos is inherent in all compounded things. Strive on with diligence.",
    "Be sure you put your feet in the right place, then stand firm.",
    "They must often change, who would be constant in happiness or wisdom.",
    "The heart has eyes which the brain knows nothing of.",
    "Nothing great was ever achieved without enthusiasm.",
    "God always takes the simplest way.",
    "Real magic in relationships means an absence of judgement of others.",
    "All serious daring starts from within.",
    "They can do all because they think they can.",
    "Act as if what you do makes a difference. It does.",
    "The journey of a thousand miles begins with one step.",
    "It is never too late to be what you might have been.",
    "He who obtains has little. He who scatters has much.",
    "A man is not old as long as he is seeking something.",
    "Ideas are the beginning points of all fortunes.",
    "The time you think you're missing, misses you too.",
    "No man was ever wise by chance.",
    "You won't skid if you stay in a rut.",
    "Patience is the companion of wisdom.",
    "Much wisdom often goes with fewer words.",
    "He who talks more is sooner exhausted.",
    "I'm not afraid of storms, for Im learning how to sail my ship.",
    "Victory belongs to the most persevering.",
    "Be slow of tongue and quick of eye.",
    "It is impossible to feel grateful and depressed in the same moment.",
    "The path to success is to take massive, determined action.",
    "Peace comes from within. Do not seek it without.",
    "Blaze with the fire that is never extinguished.",
    "There are no failures � just experiences and your reactions to them.",
    "A thing well said will be wit in all languages.",
    "Write your plans in pencil and give God the eraser.",
    "No is easier to do. Yes is easier to say.",
    "Always do your best. What you plant now, you will harvest later.",
    "If you light a lamp for somebody, it will also brighten your path.",
    "If you come to a fork in the road, take it.",
    "Life is 10% what happens to you and 90% how you react to it.",
    "Error is discipline through which we advance.",
    "Be slow of tongue and quick of eye.",
    "He who conquers others is strong; He who conquers himself is mighty.",
    "The best way to pay for a lovely moment is to enjoy it.",
    "Someone is special only if you tell them.",
    "A man is great by deeds, not by birth.",
    "No garden is without its weeds.",
    "Nobody can do everything, but everybody can do something.",
    "All great achievements require time.",
    "Never idealize others. They will never live up to your expectations.",
    "Excellence is to do a common thing in an uncommon way.",
    "No matter how hard the past, you can always begin again.",
    "I begin with an idea and then it becomes something else.",
    "May our hearts garden of awakening bloom with hundreds of flowers.",
    "Whoever is happy will make others happy, too.",
    "The bird of paradise alights only upon the hand that does not grasp.",
    "Difficulties increase the nearer we get to the goal.",
    "Act as if what you do makes a difference. It does.",
    "To accomplish great things, we must dream as well as act.",
    "It's not what happens to you, but how you react to it that matters.",
    "Take it easy � but take it.",
    "Whoever is happy will make others happy, too.",
    "Where all think alike, no one thinks very much.",
    "To accomplish great things, we must dream as well as act.",
    "The beginning is always today.",
    "Keep true to the dreams of thy youth.",
    "The winds and waves are always on the side of the ablest navigators.",
    "Take rest; a field that has rested gives a bountiful crop.",
    "May our hearts garden of awakening bloom with hundreds of flowers.",
    "Do what you can. Want what you have. Be who you are.",
    "There are people who have money and people who are rich.",
    "Why worry about tomorrow, when today is all we have?",
    "To accomplish great things, we must dream as well as act.",
    "Things do not change, we change.",
    "To be wronged is nothing unless you continue to remember it.",
    "There is no greater harm than that of time wasted.",
    "To accomplish great things, we must dream as well as act.",
    "If you cannot do great things, do small things in a great way.",
    "Experience is simply the name we give our mistakes.",
    "Most smiles are started by another smile.",
    "Think how hard physics would be if particles could think.",
    "Imagination is the highest kite one can fly.",
    "The best way out is always through.",
    "A man is not where he lives but where he loves.",
    "Experience keeps a dear school, but fools will learn in no other.",
    "The heart has eyes which the brain knows nothing of.",
    "God always takes the simplest way.",
    "Those that know, do. Those that understand, teach.",
    "He who knows himself is enlightened.",
    "The universe is transformation; our life is what our thoughts make it.",
    "You can't choose up sides on a round world.",
    "What you do not want done to yourself, do not do to others.",
    "Fortune favours the brave.",
    "A man is not old as long as he is seeking something.",
    "Happiness depends upon ourselves.",
    "Smile, breathe and go slowly.",
    "A man is not old as long as he is seeking something.",
    "Be the chief but never the lord.",
    "I may not know everything, but everything is not known yet anyway.",
    "The bird of paradise alights only upon the hand that does not grasp.",
    "You cannot travel the path until you have become the path itself.",
    "Keep your eyes on the stars and your feet on the ground.",
    "When you lose, don't lose the lesson.",
    "Character develops itself in the stream of life.",
    "If you want a thing done well, do it yourself.",
    "No one has ever become poor by giving.",
    "An obstacle may be either a stepping stone or a stumbling block.",
    "I think and that is all that I am.",
    "The greatest barrier to success is the fear of failure.",
    "The heart has eyes which the brain knows nothing of.",
    "If you aren't going all the way, why go at all?",
    "We choose our destiny in the way we treat others.",
    "Kind words do not cost much. Yet they accomplish much.",
    "I destroy my enemies when I make them my friends.",
    "Stay committed to your decisions, but stay flexible in your approach.",
    "The path to success is to take massive, determined action.",
    "Tension is who you think you should be. Relaxation is who you are.",
    "We do what we do because we believe.",
    "Silence is the true friend that never betrays.",
    "To want to be what one can be is purpose in life.",
    "Whoever is happy will make others happy, too.",
    "Character develops itself in the stream of life.",
    "Better than a thousand hollow words, is one word that brings peace.",
    "The only real valuable thing is intuition.",
    "Wisdom begins in wonder.",
    "When I let go of what I am, I become what I might be.",
    "It does not matter how slowly you go as long as you do not stop.",
    "Peace comes from within. Do not seek it without.",
    "When there is no enemy within, the enemies outside cannot hurt you.",
    "You are the only person on Earth who can use your ability.",
    "Don't let what you can't do stop you from doing what you can do.",
    "Complaining doesn't change a thing only taking action does.",
    "If you can't feed a hundred people, then feed just one.",
    "Everything that exists is in a manner the seed of that which will be.",
    "Think how hard physics would be if particles could think.",
    "Let the beauty of what you love be what you do.",
    "The world turns aside to let any man pass who knows where he is going.",
    "Beauty is not in the face; beauty is a light in the heart.",
    "A day of worry is more exhausting than a day of work.",
    "I never think of the future. It comes soon enough.",
    "It isn't where you come from, it's where you're going that counts.",
    "All I can say about life is, Oh God, enjoy it!",
    "The day is already blessed, find peace within it.",
    "Tension is who you think you should be. Relaxation is who you are.",
    "To be great is to be misunderstood.",
    "Love all, trust a few, do wrong to none.",
    "Never, never, never give up.",
    "Think as a wise man but communicate in the language of the people.",
    "They can do all because they think they can.",
    "It isn't where you come from, it's where you're going that counts.",
    "In all chaos there is a cosmos, in all disorder a secret order.",
    "It is the quality of our work which will please God, not the quantity.",
    "Try and fail, but don't fail to try.",
    "The heart has its reasons which reason knows not of.",
    "The ladder of success is never crowded at the top.",
    "You can do what's reasonable or you can decide what's possible.",
    "Nothing diminishes anxiety faster than action.",
    "Don't be afraid to go out on a limb. That's where the fruit is.",
    "Mistakes are always forgivable, if one has the courage to admit them.",
    "I allow my intuition to lead my path.",
    "Today is the tomorrow we worried about yesterday.",
    "Fear not for the future, weep not for the past.",
    "The mind is everything. What you think you become.",
    "We are Divine enough to ask and we are important enough to receive.",
    "If you kick a stone in anger, you'll hurt your own foot.",
    "Put your future in good hands � your own.",
    "All men who have achieved great things have been great dreamers.",
    "To see things in the seed, that is genius.",
    "No yesterdays are ever wasted for those who give themselves to today.",
    "I may not know everything, but everything is not known yet anyway.",
    "He who obtains has little. He who scatters has much.",
    "Chaos is inherent in all compounded things. Strive on with diligence.",
    "Make the most of yourself, for that is all there is of you.",
    "History will be kind to me for I intend to write it.",
    "In all chaos there is a cosmos, in all disorder a secret order.",
    "The universe is made of stories, not atoms.",
    "The best way to pay for a lovely moment is to enjoy it.",
    "Respect should be earned by actions, and not acquired by years.",
    "I hear and I forget. I see and I remember. I do and I understand.",
    "Do something wonderful, people may imitate it.",
    "You can do it if you believe you can!",
    "We shall never know all the good that a simple smile can do.",
    "Sometimes the biggest act of courage is a small one.",
    "Let the beauty of what you love be what you do.",
    "Strong beliefs win strong men, and then make them stronger.",
    "No man is free who is not master of himself.",
    "Waste no more time arguing about what a good man should be. Be one.",
    "Don't be afraid to go out on a limb. That's where the fruit is.",
    "Keep true to the dreams of thy youth.",
    "Great talent finds happiness in execution.",
    "Decision is a risk rooted in the courage of being free.",
    "Think as a wise man but communicate in the language of the people.",
    "He who obtains has little. He who scatters has much.",
    "It has never been my object to record my dreams, just to realize them.",
    "There is no greater harm than that of time wasted.",
    "Experience is simply the name we give our mistakes.",
    "Chaos and Order are not enemies, only opposites.",
    "You must welcome change as the rule but not as your ruler.",
    "The secret of success is constancy to purpose.",
    "Rainbows apologize for angry skies.",
    "We are Divine enough to ask and we are important enough to receive.",
    "Be kind whenever possible. It is always possible.",
    "Peace begins with a smile.",
    "Be your own hero, it's cheaper than a movie ticket.",
    "Kind words will unlock an iron door.",
    "Turn your face toward the sun and the shadows will fall behind you.",
    "Much wisdom often goes with fewer words.",
    "Great talent finds happiness in execution.",
    "Better to have loved and lost, than to have never loved at all.",
    "Go to your bosom: Knock there, and ask your heart what it doth know.",
    "Stay away from what might have been and look at what will be.",
    "No man can succeed in a line of endeavor which he does not like.",
    "Don't wait for people to be friendly. Show them how.",
    "Tension is who you think you should be. Relaxation is who you are.",
    "Can you imagine what I would do if I could do all I can?",
    "Once you choose hope, anythings possible.",
    "Ability will never catch up with the demand for it.",
    "Yeah we all shine on, like the moon, and the stars, and the sun.",
    "If one does not know to which port is sailing, no wind is favorable.",
    "It is impossible to feel grateful and depressed in the same moment.",
    "The day always looks brighter from behind a smile.",
    "Absence makes the heart grow fonder.",
    "Follow your instincts. That is where true wisdom manifests itself.",
    "A prudent question is one half of wisdom.",
    "Life is a learning experience, only if you learn.",
    "Don't let what you can't do stop you from doing what you can do.",
    "Joy is the best makeup.",
    "The mind unlearns with difficulty what it has long learned.",
    "In all chaos there is a cosmos, in all disorder a secret order.",
    "If you wish to be a writer, write.",
    "It can't be spring if your heart is filled with past failures.",
    "We may encounter many defeats but we must not be defeated.",
    "Arriving at one point is the starting point to another.",
    "Each day provides its own gifts.",
    "Logic will get you from A to B. Imagination will take you everywhere.",
    "Arriving at one point is the starting point to another.",
    "The mind unlearns with difficulty what it has long learned.",
    "Inspiration exists, but it has to find us working.",
    "Only when we are no longer afraid do we begin to live.",
    "We must not allow ourselves to become like the system we oppose.",
    "Chaos and Order are not enemies, only opposites.",
    "Never let lack of money interfere with having fun.",
    "Begin at once to live and count each separate day as a separate life.",
    "The world is but a canvas to the imagination.",
    "We choose our destiny in the way we treat others.",
    "Don't be afraid to go out on a limb. That's where the fruit is.",
    "We do what we do because we believe.",
    "Never ignore a gut feeling, but never believe that it's enough.",
    "All I can say about life is, Oh God, enjoy it!",
    "You are special, you are unique, you are the best!",
    "To be happy is to be able to become aware of oneself without fright.",
    "Make the most of yourself for that is all there is of you.",
    "No matter how hard the past, you can always begin again.",
    "Happiness is not something ready made. It comes from your own actions.",
    "Be gentle first with yourself if you wish to be gentle with others.",
    "A man who doesn't trust himself can never really trust anyone else.",
    "The journey of a thousand miles begins with one step.",
    "To be wronged is nothing unless you continue to remember it.",
    "Someone is special only if you tell them.",
    "Joy is the best makeup.",
    "We make our own fortunes and we call them fate.",
    "I hear and I forget. I see and I remember. I do and I understand.",
    "Myths which are believed in tend to become true.",
    "It takes courage to grow up and become who you really are.",
    "Always seek out the seed of triumph in every adversity.",
    "Rather than wishing for change, you first must be prepared to change.",
    "Always be smarter than the people who hire you.",
    "Fame usually comes to those who are thinking about something else.",
    "I may not know everything, but everything is not known yet anyway.",
    "It is never too late to be what you might have been.",
    "Every gift from a friend is a wish for your happiness.",
    "Only do what your heart tells you.",
    "Make the most of yourself, for that is all there is of you.",
    "Turn your face toward the sun and the shadows will fall behind you.",
    "Myths which are believed in tend to become true.",
    "What we think, we become.",
    "Peace begins with a smile.",
    "Real magic in relationships means an absence of judgement of others.",
    "Who sows virtue reaps honour.",
    "Knowledge rests not upon truth alone, but upon error also.",
    "Minds are like parachutes. They only function when open.",
    "A man is not old as long as he is seeking something.",
    "Logic will get you from A to B. Imagination will take you everywhere.",
    "Faith in oneself is the best and safest course.",
    "When deeds and words are in accord, the whole world is transformed.",
    "Take heed: you do not find what you do not seek.",
    "Yeah we all shine on, like the moon, and the stars, and the sun.",
    "No man was ever wise by chance.",
    "Better to have loved and lost, than to have never loved at all.",
    "For everything that lives is holy, life delights in life.",
    "Today is the tomorrow we worried about yesterday.",
    "Peace comes from within. Do not seek it without.",
    "Our passion is our strength.",
    "Wisdom is the supreme part of happiness.",
    "Take heed: you do not find what you do not seek.",
    "Spring is a time for rebirth and the fulfilment of new life.",
    "Being angry never solves anything.",
    "It can't be spring if your heart is filled with past failures.",
    "From little acorns mighty oaks do grow.",
    "When deeds speak, words are nothing.",
    "Nature is a mutable cloud which is always and never the same.",
    "Society develops wit, but its contemplation alone forms genius.",
    "Life is what happens while you are making other plans.",
    "Be your own hero, it's cheaper than a movie ticket.",
    "We make a living by what we get, but we make a life by what we give.",
    "Can you imagine what I would do if I could do all I can?",
    "The two most powerful warriors are patience and time.",
    "Nobody will believe in you unless you believe in yourself.",
    "Open minds lead to open doors.",
    "You are special, you are unique, you are the best!",
    "Real magic in relationships means an absence of judgement of others.",
    "Make the most of yourself for that is all there is of you.",
    "Happiness is found in doing, not merely possessing.",
    "The world is but a canvas to the imagination.",
    "You'll see it when you believe it.",
    "We make our own fortunes and we call them fate.",
    "A prudent question is one half of wisdom.",
    "Experience keeps a dear school, but fools will learn in no other.",
    "Thought is the blossom; language the bud; action the fruit behind it.",
    "A rolling stone gathers no moss.",
    "Every problem has a gift for you in its hands.",
    "To be wronged is nothing unless you continue to remember it.",
    "If a man does his best, what else is there?",
    "Take heed: you do not find what you do not seek.",
    "If you can't feed a hundred people, then feed just one.",
    "It isn't where you come from, it's where you're going that counts.",
    "Silence is a source of great strength.",
    "To be tested is good. The challenged life may be the best therapist.",
    "Can you imagine what I would do if I could do all I can?",
    "To bring anything into your life, imagine that it's already there.",
    "The most successful people are those who are good at plan B.",
    "Mountains cannot be surmounted except by winding paths.",
    "Only do what your heart tells you.",
    "Smile, breathe, and go slowly.",
    "Kind words do not cost much. Yet they accomplish much.",
    "Great ideas often receive violent opposition from mediocre minds.",
    "The winds and waves are always on the side of the ablest navigators.",
    "We can change our lives. We can do, have, and be exactly what we wish.",
    "Only those who dare to fail greatly can ever achieve greatly.",
    "You are the only person on earth who can use your ability.",
    "When you lose, don't lose the lesson.",
    "Kindness is the greatest wisdom.",
    "We may encounter many defeats but we must not be defeated.",
    "Every day may not be good, but there's something good in every day.",
    "A stumble may prevent a fall.",
    "The pain passes, but the beauty remains.",
    "Meaning is not what you start with but what you end up with.",
    "You can't trust without risk but neither can you live in a cocoon.",
    "To know oneself is to study oneself in action with another person.",
    "No man can succeed in a line of endeavor which he does not like.",
    "Learn from yesterday, live for today, hope for tomorrow.",
    "Don't think of it as failure. Think of it as time-released success.",
    "You can't trust without risk but neither can you live in a cocoon.",
    "The doors we open and close each day decide the lives we live.",
    "You cannot travel the path until you have become the path itself.",
    "I walk slowly, but I never walk backward.",
    "Where there is great love, there are always miracles.",
    "Change your thoughts, change your life!",
    "The best place to find a helping hand is at the end of your own arm.",
    "Every human being is the author of his own health or disease.",
    "It is better to understand a little than to misunderstand a lot.",
    "Knowing is not enough; we must apply!",
    "We know the truth, not only by the reason, but by the heart.",
    "We choose our joys and sorrows long before we experience them.",
    "Anybody can make history. Only a great man can write it.",
    "If I know what love is, it is because of you.",
    "The best teacher is experience learned from failures.",
    "The years teach much which the days never know.",
    "Self-trust is the first secret of success.",
    "The harder you fall, the higher you bounce.",
    "Myths which are believed in tend to become true.",
    "Nature takes away any faculty that is not used.",
    "Patience is the companion of wisdom.",
    "Meaning is not what you start with but what you end up with.",
    "Be here now. Be someplace else later. Is that so complicated?",
    "If it is not right do not do it; if it is not true do not say it.",
    "You can do it if you believe you can!",
    "Nothing happens unless first we dream.",
    "In the middle of every difficulty lies opportunity.",
    "The best way to pay for a lovely moment is to enjoy it.",
    "Learn from yesterday, live for today, hope for tomorrow.",
    "Beauty is not in the face; beauty is a light in the heart.",
    "A jug fills drop by drop.",
    "The less effort, the faster and more powerful you will be.",
    "Self-complacency is fatal to progress.",
    "Write your plans in pencil and give God the eraser.",
    "A rolling stone gathers no moss.",
    "Freedom is the right to live as we wish.",
    "The cure for boredom is curiosity. There is no cure for curiosity.",
    "The greatest barrier to success is the fear of failure.",
    "When there is no enemy within, the enemies outside cannot hurt you.",
    "We can do no great things, only small things with great love.",
    "Work out your own salvation. Do not depend on others.",
    "Be like the flower, turn your face to the sun.",
    "Remembering a wrong is like carrying a burden on the mind.",
    "He that is giddy thinks the world turns round.",
    "Gratitude is the fairest blossom which springs from the soul.",
    "Nothing happens unless first we dream.",
    "There are no failures � just experiences and your reactions to them.",
    "The heart has eyes which the brain knows nothing of.",
    "Life shrinks or expands in proportion to one's courage.",
    "You cannot have what you do not want.",
    "You have to believe in yourself.",
    "All the flowers of all the tomorrows are in the seeds of today.",
    "It is not fair to ask of others what you are unwilling to do yourself.",
    "One today is worth two tomorrows.",
    "You have to think anyway, so why not think big?",
    "Don't let today's disappointments cast a shadow on tomorrow's dreams.",
    "I walk slowly, but I never walk backward.",
    "To be upset over what you don't have is to waste what you do have.",
    "No one has ever become poor by giving.",
    "Better than a thousand hollow words, is one word that brings peace.",
    "Truth is powerful and it prevails.",
    "Don't ruin the present with the ruined past.",
    "Blaze with the fire that is never extinguished.",
    "If you do not change direction, you may end up where you are heading.",
    "The world is a book, and those who do not travel read only a page.",
    "The best thing in every noble dream is the dreamer...",
    "Spring is a time for rebirth and the fulfilment of new life.",
    "Every man is a volume if you know how to read him.",
    "Weve got to have a dream if we are going to make a dream come true.",
    "I hear and I forget. I see and I remember. I do and I understand.",
    "In order to win, you must expect to win.",
    "There is nothing impossible to him who will try.",
    "We must become the change we want to see.",
    "Never mistake activity for achievement.",
    "Waste no more time arguing about what a good man should be. Be one.",
    "Freedom is not worth having if it does not connote freedom to err.",
    "The only real failure in life is not to be true to the best one knows.",
    "Three things cannot be long hidden: the sun, the moon, and the truth.",
    "He who talks more is sooner exhausted.",
    "I begin with an idea and then it becomes something else.",
    "Those who cannot learn from history are doomed to repeat it.",
    "Why worry about tomorrow, when today is all we have?",
    "Every man dies. Not every man really lives.",
    "They must often change, who would be constant in happiness or wisdom.",
    "Difficulties are things that show a person what they are.",
    "Our distrust is very expensive.",
    "Happiness is not something ready made. It comes from your own actions.",
    "The one who always loses, is the only person who gets the reward.",
    "Things that were hard to bear are sweet to remember.",
    "We can change our lives. We can do, have, and be exactly what we wish.",
    "The heart has eyes which the brain knows nothing of.",
    "To know oneself is to study oneself in action with another person.",
    "Only those who dare to fail greatly can ever achieve greatly.",
    "Peace begins with a smile.",
    "Stay committed to your decisions, but stay flexible in your approach.",
    "The only limit to your impact is your imagination and commitment.",
    "No matter how hard the past, you can always begin again.",
    "It is better to understand a little than to misunderstand a lot.",
    "No man can succeed in a line of endeavor which he does not like.",
    "Autumn is a second spring when every leaf is a flower.",
    "Each day can be one of triumph if you keep up your interests.",
    "They can conquer who believe they can.",
    "Know, first, who you are, and then adorn yourself accordingly.",
    "I always wanted to be somebody, but I should have been more specific.",
    "To enjoy life, we must touch much of it lightly.",
    "We do what we do because we believe.",
    "All action results from thought, so it is thoughts that matter.",
    "As we risk ourselves, we grow. Each new experience is a risk.",
    "The cure for boredom is curiosity. There is no cure for curiosity.",
    "Rather than wishing for change, you first must be prepared to change.",
    "You'll see it when you believe it.",
    "Everyone smiles in the same language.",
    "Yesterdays home runs don't win today's games.",
    "Just as much as we see in others we have in ourselves.",
    "Stay committed to your decisions, but stay flexible in your approach.",
    "The most successful people are those who are good at plan B.",
    "He who knows, does not speak. He who speaks, does not know.",
    "We cannot direct the wind but we can adjust the sails.",
    "He who conquers others is strong; He who conquers himself is mighty.",
    "Life is a process. We are a process. The universe is a process.",
    "One may say the eternal mystery of the world is its comprehensibility.",
    "Once you choose hope, anythings possible.",
    "Real magic in relationships means an absence of judgement of others.",
    "Yesterdays home runs don't win today's games.",
    "Wherever you go, go with all your heart.",
    "Nothing is at last sacred but the integrity of your own mind.",
    "Moments of complete apathy are the best for new creations.",
    "The only real mistake is the one from which we learn nothing.",
    "You are the only person on earth who can use your ability.",
    "Myths which are believed in tend to become true.",
    "Don't let today's disappointments cast a shadow on tomorrow's dreams.",
    "All serious daring starts from within.",
    "The universe is transformation; our life is what our thoughts make it.",
    "Do good by stealth, and blush to find it fame.",
    "Things do not change; we change.",
    "Excellence is not a skill. It is an attitude.",
    "You have to think anyway, so why not think big?",
    "The harder you fall, the higher you bounce.",
    "Always seek out the seed of triumph in every adversity.",
    "To be upset over what you don't have is to waste what you do have.",
    "Yesterdays home runs don't win today's games.",
    "Act as if what you do makes a difference. It does.",
    "Be a good listener. Your ears will never get you in trouble.",
    "Every day may not be good, but there's something good in every day.",
    "The heart has eyes which the brain knows nothing of.",
    "What we see is mainly what we look for.",
    "It is impossible to feel grateful and depressed in the same moment.",
    "The best place to find a helping hand is at the end of your own arm.",
    "Strong beliefs win strong men, and then make them stronger.",
    "In order to win, you must expect to win.",
    "A beautiful thing is never perfect.",
    "You give before you get.",
    "There are no failures. Just experiences and your reactions to them.",
    "Don't let today's disappointments cast a shadow on tomorrow's dreams.",
    "You only lose what you cling to.",
    "There is only one happiness in life, to love and be loved.",
    "Happiness is found in doing, not merely possessing.",
    "He who is contented is rich.",
    "Reason and free inquiry are the only effectual agents against error.",
    "Moments of complete apathy are the best for new creations.",
    "You can't choose up sides on a round world.",
    "The best cure for the body is a quiet mind.",
    "See the positive side, the potential, and make an effort.",
    "Life is movement-we breathe, we eat, we walk, we move!",
    "You cannot be lonely if you like the person you're alone with.",
    "Why worry about tomorrow, when today is all we have?",
    "We know the truth, not only by the reason, but by the heart.",
    "Fame usually comes to those who are thinking about something else.",
    "The truest wisdom is a resolute determination.",
    "Never, never, never give up.",
    "The best thing in every noble dream is the dreamer...",
    "Everyone smiles in the same language.",
    "If you want a thing done well, do it yourself.",
    "Take heed: you do not find what you do not seek.",
    "Waste no more time arguing about what a good man should be. Be one.",
    "Yesterday I dared to struggle. Today I dare to win.",
    "Be a good listener. Your ears will never get you in trouble.",
    "Kind words do not cost much. Yet they accomplish much.",
    "Be kind whenever possible. It is always possible.",
    "When fate hands us a lemon, lets try to make lemonade.",
    "Go put your creed into the deed. Nor speak with double tongue.",
    "Wrinkles should merely indicate where smiles have been.",
    "Your attitude, not your aptitude, will determine your altitude.",
    "Don't be afraid to go out on a limb. That's where the fruit is.",
    "If you can dream it, you can do it.",
    "Where all think alike, no one thinks very much.",
    "The undertaking of a new action brings new strength.",
    "What you see depends on what you're looking for.",
    "Be your own hero, it's cheaper than a movie ticket.",
    "I gave my life to become the person I am right now. Was it worth it?",
    "Give thanks for a little and you will find a lot.",
    "Most powerful is he who has himself in his own power.",
    "When you doubt your power, you give power to your doubt.",
    "Mistakes are always forgivable, if one has the courage to admit them.",
    "Forgiveness does not change the past, but it does enlarge the future.",
    "I think and that is all that I am.",
    "In the middle of every difficulty lies opportunity.",
    "Fame usually comes to those who are thinking about something else.",
    "If one does not know to which port is sailing, no wind is favorable.",
    "The deepest craving of human nature is the need to be appreciated.",
    "If you can dream it, you can do it.",
    "The odds of hitting your target go up dramatically when you aim at it.",
    "I cannot make my days longer so I strive to make them better.",
    "Fortune befriends the bold.",
    "Excellence is not a skill. It is an attitude.",
    "Your attitude, not your aptitude, will determine your altitude.",
    "Life is a learning experience, only if you learn.",
    "If you can dream it, you can do it.",
    "Kind words do not cost much. Yet they accomplish much.",
    "We cannot direct the wind but we can adjust the sails.",
    "Every gift from a friend is a wish for your happiness.",
    "When people are like each other they tend to like each other.",
    "I always wanted to be somebody, but I should have been more specific.",
    "You can't trust without risk but neither can you live in a cocoon.",
    "All I can say about life is, Oh God, enjoy it!",
    "There is only one happiness in life, to love and be loved.",
    "The eye sees only what the mind is prepared to comprehend.",
    "Well begun is half done.",
    "Don't think of it as failure. Think of it as time-released success.",
    "Meaning is not what you start with but what you end up with.",
    "Be the change that you want to see in the world.",
    "The most formidable weapon against errors of every kind is reason.",
    "The more you care, the stronger you can be.",
    "A good rest is half the work.",
    "Goals are the fuel in the furnace of achievement.",
    "He who is contented is rich.",
    "God always takes the simplest way.",
    "Just trust yourself, then you will know how to live.",
    "Formula for success: under promise and over deliver.",
    "Everything in life is luck.",
    "Our intention creates our reality.",
    "A good rest is half the work.",
    "You won't skid if you stay in a rut.",
    "We must become the change we want to see.",
    "A rolling stone gathers no moss.",
    "Change in all things is sweet.",
    "Fame usually comes to those who are thinking about something else.",
    "There is only one happiness in life, to love and be loved.",
    "Worry often gives a small thing a big shadow.",
    "It does not matter how slowly you go as long as you do not stop.",
    "Nature is a mutable cloud which is always and never the same.",
    "We aim above the mark to hit the mark.",
    "Be like the flower, turn your face to the sun.",
    "He who talks more is sooner exhausted.",
    "To climb steep hills requires a slow pace at first.",
    "There is nothing impossible to him who will try.",
    "Truth is generally the best vindication against slander.",
    "All achievements, all earned riches, have their beginning in an idea.",
    "To follow, without halt, one aim: There is the secret of success.",
    "When the solution is simple, God is answering.",
    "Imagination is the highest kite one can fly.",
    "The universe is transformation; our life is what our thoughts make it.",
    "What is a weed? A plant whose virtues have not yet been discovered.",
    "Those who cannot learn from history are doomed to repeat it.",
    "Be less curious about people and more curious about ideas.",
    "We choose our destiny in the way we treat others.",
    "We read the world wrong and say that it deceives us.",
    "If only wed stop trying to be happy wed have a pretty good time.",
    "Don't cry because it's over. Smile because it happened.",
    "You must do the things you think you cannot do.",
    "The path to success is to take massive, determined action.",
    "One may say the eternal mystery of the world is its comprehensibility.",
    "To be upset over what you don't have is to waste what you do have.",
    "Meaning is not what you start with but what you end up with.",
    "Be yourself; everyone else is already taken.",
    "Loss is nothing else but change,and change is Natures delight.",
    "When deeds speak, words are nothing.",
    "A rolling stone gathers no moss.",
    "Things do not change; we change.",
    "Know, first, who you are, and then adorn yourself accordingly.",
    "You cannot have what you do not want.",
    "I cannot make my days longer so I strive to make them better.",
    "Thought is the blossom; language the bud; action the fruit behind it.",
    "For everything that lives is holy, life delights in life.",
    "Don't smother each other. No one can grow in the shade.",
    "The bird of paradise alights only upon the hand that does not grasp.",
    "To be upset over what you don't have is to waste what you do have.",
    "Nothing great was ever achieved without enthusiasm.",
    "A thing well said will be wit in all languages.",
    "Myths which are believed in tend to become true.",
    "The greatest remedy for anger is delay.",
    "Those who are free of resentful thoughts surely find peace.",
    "Great acts are made up of small deeds.",
    "I gave my life to become the person I am right now. Was it worth it?",
    "Most folks are as happy as they make up their minds to be.",
    "What you see depends on what you're looking for.",
    "If it is not right do not do it; if it is not true do not say it.",
    "Love is the master key that opens the gates of happiness.",
    "What we achieve inwardly will change outer reality.",
    "If I know what love is, it is because of you.",
    "Tension is who you think you should be. Relaxation is who you are.",
    "My reputation grows with every failure.",
    "We know what we are, but know not what we may be.",
    "Time is the wisest counsellor of all.",
    "Good thoughts are no better than good dreams, unless they be executed.",
    "Success is getting what you want. Happiness is wanting what you get.",
    "The only real failure in life is not to be true to the best one knows.",
    "Skill to do comes of doing.",
    "As we risk ourselves, we grow. Each new experience is a risk.",
    "Be slow of tongue and quick of eye.",
    "I always wanted to be somebody, but I should have been more specific.",
    "The greatest barrier to success is the fear of failure.",
    "For success, attitude is equally as important as ability.",
    "If you correct your mind, the rest of your life will fall into place.",
    "Knowledge rests not upon truth alone, but upon error also.",
    "You can observe a lot just by watching.",
    "A person who never made a mistake never tried anything new.",
    "Better than a thousand hollow words is one word that brings peace.",
    "The possibilities are numerous once we decide to act and not react.",
    "When fate hands us a lemon, lets try to make lemonade.",
    "We can only learn to love by loving.",
    "He who obtains has little. He who scatters has much.",
    "Self-trust is the first secret of success.",
    "To be wrong is nothing unless you continue to remember it.",
    "Don't compromise yourself. You are all you've got.",
    "Never ignore a gut feeling, but never believe that it's enough.",
    "Well done is better than well said.",
    "Almost everything comes from nothing.",
    "It isn't where you come from, it's where you're going that counts.",
    "He who is contented is rich.",
    "Where all think alike, no one thinks very much.",
    "I never think of the future. It comes soon enough.",
    "Sometimes by losing a battle you find a new way to win the war.",
    "Listen to what you know instead of what you fear.",
    "When you doubt your power, you give power to your doubt.",
    "The greatest obstacle to connecting with our joy is resentment.",
    "Remember that failure is an event, not a person.",
    "Why worry about tomorrow, when today is all we have?",
    "From little acorns mighty oaks do grow.",
    "Don't settle for a relationship that won't let you be yourself.",
    "Wherever a man turns he can find someone who needs him.",
    "Not what we have but what we enjoy constitutes our abundance.",
    "As you think, so shall you become.",
    "God has given you one face, and you make yourself another.",
    "Bite off more than you can chew, then chew it.",
    "The only limit to your impact is your imagination and commitment.",
    "Nothing diminishes anxiety faster than action.",
    "Memory is the mother of all wisdom.",
    "Freedom is what you do with what's been done to you.",
    "Do not wait for leaders; do it alone, person to person.",
    "Never ignore a gut feeling, but never believe that it's enough.",
    "The price of greatness is responsibility.",
    "You don't drown by falling in water. You drown by staying there.",
    "Don't talk about what you have done or what you are going to do.",
    "Everything in life is luck.",
    "Science is organized knowledge. Wisdom is organized life.",
    "I'm not afraid of storms, for Im learning how to sail my ship.",
    "It is fatal to enter any war without the will to win it.",
    "Life is just a chance to grow a soul.",
    "You can observe a lot just by watching.",
    "We never live; we are always in the expectation of living.",
    "Think like a man of action; act like a man of thought.",
    "The beginning is always today.",
    "The universe is transformation; our life is what our thoughts make it.",
    "Well done is better than well said.",
    "I always wanted to be somebody, but I should have been more specific.",
    "Always do your best. What you plant now, you will harvest later.",
    "If it is not right do not do it; if it is not true do not say it.",
    "Time you enjoyed wasting was not wasted.",
    "Your big opportunity may be right where you are now.",
    "Do something wonderful, people may imitate it.",
    "A man's dreams are an index to his greatness.",
    "Everyone smiles in the same language.",
    "There is no way to happiness, happiness is the way.",
    "What you do not want done to yourself, do not do to others.",
    "Why worry about tomorrow, when today is all we have?",
    "Know, first, who you are, and then adorn yourself accordingly.",
    "Try and fail, but don't fail to try.",
    "Your big opportunity may be right where you are now.",
    "Intuition will tell the thinking mind where to look next.",
    "Our intention creates our reality.",
    "Strong beliefs win strong men, and then make them stronger.",
    "Ignorance never settle a question.",
    "Set your goals high, and don't stop till you get there.",
    "Whoever is happy will make others happy, too.",
    "To follow, without halt, one aim: There is the secret of success.",
    "A stumble may prevent a fall.",
    "The years teach much which the days never know.",
    "God has given you one face, and you make yourself another.",
    "You teach best what you most need to learn.",
    "Watch the little things; a small leak will sink a great ship.",
    "Be yourself; everyone else is already taken.",
    "To be tested is good. The challenged life may be the best therapist.",
    "Sooner or later, those who win are those who think they can.",
    "Fortune favours the brave.",
    "The heart has its reasons which reason knows not of.",
    "Go for it now. The future is promised to no one.",
    "When you doubt your power, you give power to your doubt.",
    "Don't let what you can't do stop you from doing what you can do.",
    "Our passion is our strength.",
    "Learning is a treasure that will follow its owner everywhere",
    "The best way to pay for a lovely moment is to enjoy it.",
    "Loss is nothing else but change,and change is Natures delight.",
    "Whatever happens, take responsibility.",
    "We must not say every mistake is a foolish one.",
    "The day always looks brighter from behind a smile.",
    "From small beginnings come great things.",
    "Open minds lead to open doors.",
    "In skating over thin ice our safety is in our speed.",
    "To want to be what one can be is purpose in life.",
    "Never promise more than you can perform.",
    "The greatest remedy for anger is delay.",
    "He who fears being conquered is sure of defeat.",
    "Do not turn back when you are just at the goal.",
    "When in doubt, tell the truth.",
    "Every problem has a gift for you in its hands.",
    "As you think, so shall you become.",
    "The cautious seldom err.",
    "Be less curious about people and more curious about ideas.",
    "As you think, so shall you become.",
    "The future belongs to those who believe in the beauty of their dreams.",
    "I can't believe that God put us on this earth to be ordinary.",
    "There are no limitations to the mind except those we acknowledge.",
    "You won't skid if you stay in a rut.",
    "Ignorance never settle a question.",
    "To fly, we have to have resistance.",
    "Things do not change; we change.",
    "He who angers you conquers you.",
    "Don't think of it as failure. Think of it as time-released success.",
    "Every problem has a gift for you in its hands.",
    "The future is completely open, and we are writing it moment to moment.",
    "Nothing in life is to be feared. It is only to be understood.",
    "Everyone smiles in the same language.",
    "Well done is better than well said.",
    "No is easier to do. Yes is easier to say.",
    "Myths which are believed in tend to become true.",
    "You can do what's reasonable or you can decide what's possible.",
    "He who fears being conquered is sure of defeat.",
    "You can do it if you believe you can!",
    "He who angers you conquers you.",
    "Everyone smiles in the same language.",
    "I have often regretted my speech, never my silence.",
    "Never promise more than you can perform.",
    "Complaining doesn't change a thing only taking action does.",
    "If you wish to be a writer, write.",
    "When people are like each other they tend to like each other.",
    "We must not say every mistake is a foolish one.",
    "The way is not in the sky. The way is in the heart.",
    "Once we accept our limits, we go beyond them.",
    "Shoot for the moon. Even if you miss, you'll land among the stars.",
    "Think for yourselves and let others enjoy the privilege to do so too.",
    "Take it easy � but take it.",
    "No garden is without its weeds.",
    "Life shrinks or expands in proportion to one's courage.",
    "The winds and waves are always on the side of the ablest navigators.",
    "No yesterdays are ever wasted for those who give themselves to today.",
    "Change your words. Change your world.",
    "Study the past, if you would divine the future.",
    "God has given you one face, and you make yourself another.",
    "The only real valuable thing is intuition.",
    "It is never too late to be what you might have been.",
    "People seldom notice old clothes if you wear a big smile.",
    "It does not matter how slowly you go as long as you do not stop.",
    "What we think, we become.",
    "The foot feels the foot when it feels the ground.",
    "Rainbows apologize for angry skies.",
    "Life isn't about finding yourself. Life is about creating yourself.",
    "He who knows others is wise. He who knows himself is enlightened.",
    "An ant on the move does more than a dozing ox",
    "The journey of a thousand miles begins with one step.",
    "Once we accept our limits, we go beyond them.",
    "Moments of complete apathy are the best for new creations.",
    "The best way to predict your future is to create it.",
    "To avoid criticism, do nothing, say nothing, be nothing.",
    "To accomplish great things, we must dream as well as act.",
    "Fear is a darkroom where negatives develop.",
    "Life is what you make of it. Always has been, always will be.",
    "To see things in the seed, that is genius.",
    "Whoever is happy will make others happy, too.",
    "It's not what happens to you, but how you react to it that matters.",
    "Anybody can make history. Only a great man can write it.",
    "Difficulties are things that show a person what they are.",
    "A goal without a plan is just a wish.",
    "We shall never know all the good that a simple smile can do.",
    "The harder you fall, the higher you bounce.",
    "The way is not in the sky. The way is in the heart.",
    "Light tomorrow with today!",
    "Forgiveness does not change the past, but it does enlarge the future.",
    "You won't skid if you stay in a rut.",
    "Never mistake motion for action.",
    "Your attitude, not your aptitude, will determine your altitude.",
    "A goal without a plan is just a wish.",
    "I have often regretted my speech, never my silence.",
    "Your attitude, not your aptitude, will determine your altitude.",
    "Ability will never catch up with the demand for it.",
    "To be happy is to be able to become aware of oneself without fright.",
    "You only lose what you cling to.",
    "A weed is no more than a flower in disguise.",
    "The secret to a rich life is to have more beginnings than endings.",
    "Nothing ever goes away until it has taught us what we need to know.",
    "The universe is transformation; our life is what our thoughts make it.",
    "Meaning is not what you start with but what you end up with.",
    "Logic will get you from A to B. Imagination will take you everywhere.",
    "A short saying oft contains much wisdom.",
    "Self-complacency is fatal to progress.",
    "What is not started today is never finished tomorrow.",
    "Bite off more than you can chew, then chew it.",
    "Ignorance never settle a question.",
    "A weed is no more than a flower in disguise.",
    "Real success is finding your lifework in the work that you love.",
    "Great talent finds happiness in execution.",
    "The deepest craving of human nature is the need to be appreciated.",
    "Where there is great love, there are always miracles.",
    "I allow my intuition to lead my path.",
    "Never, never, never give up.",
    "From little acorns mighty oaks do grow.",
    "I believe that every person is born with talent.",
    "Can you imagine what I would do if I could do all I can?",
    "Keep true to the dreams of thy youth.",
    "Most smiles are started by another smile.",
    "If you can't explain it simply, you don't understand it well enough.",
    "All know the way; few actually walk it.",
    "Life shrinks or expands in proportion to one's courage.",
    "The cause is hidden. The effect is visible to all.",
    "If one does not know to which port is sailing, no wind is favorable.",
    "I think and that is all that I am.",
    "Nothing in life is to be feared. It is only to be understood.",
    "He who lives in harmony with himself lives in harmony with the world.",
    "To know oneself is to study oneself in action with another person.",
    "Doing nothing is better than being busy doing nothing.",
    "Change your thoughts, change your life!",
    "All I can say about life is, Oh God, enjoy it!",
    "Real magic in relationships means an absence of judgement of others.",
    "Problems are only opportunities with thorns on them.",
    "He who knows himself is enlightened.",
    "I think and that is all that I am.",
    "Fortune favours the brave.",
    "The secret of success is constancy to purpose.",
    "Absence makes the heart grow fonder.",
    "The best place to find a helping hand is at the end of your own arm.",
    "I have no special talent. I am only passionately curious.",
    "He who knows others is wise. He who knows himself is enlightened.",
    "Self-complacency is fatal to progress.",
    "Remember that failure is an event, not a person.",
    "In the middle of every difficulty lies opportunity.",
    "Yesterday I dared to struggle. Today I dare to win.",
    "You always succeed in producing a result.",
    "You are the only person on earth who can use your ability.",
    "To be wrong is nothing unless you continue to remember it.",
    "A man who doesn't trust himself can never really trust anyone else.",
    "It takes both sunshine and rain to make a rainbow.",
    "You can do it if you believe you can!",
    "Change in all things is sweet.",
    "They can do all because they think they can.",
    "The two most powerful warriors are patience and time.",
    "If you come to a fork in the road, take it.",
    "You cannot be lonely if you like the person you're alone with.",
    "Freedom is the right to live as we wish.",
    "Self-complacency is fatal to progress.",
    "It has never been my object to record my dreams, just to realize them.",
    "Wisdom begins in wonder.",
    "We know what we are, but know not what we may be.",
    "What is a weed? A plant whose virtues have not yet been discovered.",
    "To be wronged is nothing unless you continue to remember it.",
    "How we spend our days is, of course, how we spend our lives.",
    "To accomplish great things, we must dream as well as act.",
    "If we did the things we are capable of, we would astound ourselves.",
    "You are the only person on Earth who can use your ability.",
    "Success is getting what you want. Happiness is wanting what you get.",
    "Never idealize others. They will never live up to your expectations.",
    "Those who will play with cats must expect to be scratched.",
    "Today is the tomorrow you worried about yesterday.",
    "Every gift from a friend is a wish for your happiness.",
    "When performance exceeds ambition, the overlap is called success.",
    "We choose our destiny in the way we treat others.",
    "You won't skid if you stay in a rut.",
    "Well begun is half done.",
    "The years teach much which the days never know.",
    "Set your goals high, and don't stop till you get there.",
    "An obstacle may be either a stepping stone or a stumbling block.",
    "Absence makes the heart grow fonder.",
    "From error to error one discovers the entire truth.",
    "A person who never made a mistake never tried anything new.",
    "If you get up one more time than you fall, you will make it through.",
    "To get the full value of joy you must have someone to divide it with.",
    "We never live; we are always in the expectation of living.",
    "To be happy is to be able to become aware of oneself without fright.",
    "We lost because we told ourselves we lost.",
    "Our passion is our strength.",
    "You teach best what you most need to learn.",
    "Worry gives a small thing a big shadow.",
    "You can do it if you believe you can!",
    "No act of kindness, no matter how small, is ever wasted.",
    "A man's dreams are an index to his greatness.",
    "Without some goals and some efforts to reach it, no man can live.",
    "He who knows, does not speak. He who speaks, does not know.",
    "The only real valuable thing is intuition.",
    "Do not wait for leaders; do it alone, person to person.",
    "Whatever happens, take responsibility.",
    "Keep your eyes on the stars and your feet on the ground.",
    "Success is determined by those whom prove the impossible, possible.",
    "Worry often gives a small thing a big shadow.",
    "We shall never know all the good that a simple smile can do.",
    "The only real failure in life is not to be true to the best one knows.",
    "God has given you one face, and you make yourself another.",
    "Wherever a man turns he can find someone who needs him.",
    "The best way out is always through.",
    "You are special, you are unique, you are the best!",
    "Truth is powerful and it prevails.",
    "When you learn, teach. When you get, give.",
    "A man's dreams are an index to his greatness.",
    "Truth is powerful and it prevails.",
    "The wisest men follow their own direction.",
    "Think how hard physics would be if particles could think.",
    "To follow, without halt, one aim: There is the secret of success.",
    "If you kick a stone in anger, you'll hurt your own foot.",
    "Intuition will tell the thinking mind where to look next.",
    "We cannot direct the wind but we can adjust the sails.",
    "Life is what happens to you while you're busy making other plans.",
    "When there is no enemy within, the enemies outside cannot hurt you.",
    "Don't be pushed by your problems; be led by your dreams.",
    "Truth is powerful and it prevails.",
    "If you wish to be a writer, write.",
    "In seed time learn, in harvest teach, in winter enjoy.",
    "Take heed: you do not find what you do not seek.",
    "Knowledge rests not upon truth alone, but upon error also.",
    "No man was ever wise by chance.",
    "If you have knowledge, let others light their candles in it.",
    "To get the full value of joy you must have someone to divide it with.",
    "It is impossible for a man to learn what he thinks he already knows.",
    "Silence is deep as Eternity, Speech is shallow as Time.",
    "If you find yourself in a hole, the first thing to do is stop digging.",
    "I have no special talent. I am only passionately curious.",
    "It isn't where you come from, it's where you're going that counts.",
    "Those who will play with cats must expect to be scratched.",
    "Action is the foundational key to all success.",
    "To see things in the seed, that is genius.",
    "Don't smother each other. No one can grow in the shade.",
    "Sooner or later, those who win are those who think they can.",
    "Goals are the fuel in the furnace of achievement.",
    "A goal without a plan is just a wish.",
    "Logic will get you from A to B. Imagination will take you everywhere.",
    "No yesterdays are ever wasted for those who give themselves to today.",
    "Autumn is a second spring when every leaf is a flower.",
    "There are no failures � just experiences and your reactions to them.",
    "From small beginnings come great things.",
    "Well done is better than well said.",
    "Be sure you put your feet in the right place, then stand firm.",
    "I never worry about action, but only inaction.",
    "The energy of the mind is the essence of life.",
    "To be happy is to be able to become aware of oneself without fright.",
    "In skating over thin ice our safety is in our speed.",
    "Kindness is the greatest wisdom.",
    "To bring anything into your life, imagine that it's already there.",
    "What you give is what you get.",
    "The secret of success is constancy to purpose.",
    "Our intention creates our reality.",
    "The best place to find a helping hand is at the end of your own arm.",
    "Begin, be bold, and venture to be wise.",
    "There are people who have money and people who are rich.",
    "While we stop to think, we often miss our opportunity.",
    "You only lose what you cling to.",
    "You give before you get.",
    "Do good by stealth, and blush to find it fame.",
    "Action will remove the doubts that theory cannot solve.",
    "Spring is a time for rebirth and the fulfilment of new life.",
    "Only do what your heart tells you.",
    "You cannot have what you do not want.",
    "Great acts are made up of small deeds.",
    "Always seek out the seed of triumph in every adversity.",
    "You must welcome change as the rule but not as your ruler.",
    "When you come to the end of your rope, tie a knot and hang on.",
    "The more you care, the stronger you can be.",
    "Real magic in relationships means an absence of judgement of others.",
    "He who knows, does not speak. He who speaks, does not know.",
    "If the shoe doesn't fit, must we change the foot?",
    "To be upset over what you don't have is to waste what you do have.",
    "It is better to travel well than to arrive.",
    "Time you enjoyed wasting was not wasted.",
    "A wise man will make more opportunities than he finds.",
    "To climb steep hills requires a slow pace at first.",
    "Talk doesn't cook rice.",
    "If you light a lamp for somebody, it will also brighten your path.",
    "Everyone smiles in the same language.",
    "A good rest is half the work.",
    "God has given you one face, and you make yourself another.",
    "When deeds speak, words are nothing.",
    "Only those who dare to fail greatly can ever achieve greatly.",
    "Be the change that you want to see in the world.",
    "Smile, breathe, and go slowly.",
    "Arriving at one point is the starting point to another.",
    "Whoever is happy will make others happy, too.",
    "The difficulties of life are intended to make us better, not bitter.",
    "We can do no great things, only small things with great love.",
    "Begin to weave and God will give you the thread.",
    "Impossibilities are merely things which we have not yet learned.",
    "Don't be pushed by your problems; be led by your dreams.",
    "Life is what happens while you are making other plans.",
    "Science is organized knowledge. Wisdom is organized life.",
    "To know oneself is to study oneself in action with another person.",
    "From error to error one discovers the entire truth.",
    "Faith in oneself is the best and safest course.",
    "All great achievements require time.",
    "Miracles come in moments. Be ready and willing.",
    "One today is worth two tomorrows.",
    "Be a good listener. Your ears will never get you in trouble.",
    "If you kick a stone in anger, you'll hurt your own foot.",
    "A stumble may prevent a fall.",
    "Good luck is another name for tenacity of purpose.",
    "Better than a thousand hollow words, is one word that brings peace.",
    "Skill to do comes of doing.",
    "The best place to find a helping hand is at the end of your own arm.",
    "Meaning is not what you start with but what you end up with.",
    "Numberless are the worlds wonders, but none more wonderful than man.",
    "Either you run the day or the day runs you.",
    "Once we accept our limits, we go beyond them.",
    "Formula for success: under promise and over deliver.",
    "Nothing in life is to be feared. It is only to be understood.",
    "Time you enjoy wasting, was not wasted.",
    "Life isn't about finding yourself. Life is about creating yourself.",
    "The more you care, the stronger you can be.",
    "To want to be what one can be is purpose in life.",
    "Fortune befriends the bold.",
    "Love is the master key that opens the gates of happiness.",
    "Reality leaves a lot to the imagination.",
    "I know but one freedom and that is the freedom of the mind.",
    "Change your words. Change your world.",
    "The most successful people are those who are good at plan B.",
    "Luck is what happens when preparation meets opportunity.",
    "A man should look for what is, and not for what he thinks should be.",
    "You are the only person on earth who can use your ability.",
    "Fortune befriends the bold.",
    "Worry gives a small thing a big shadow.",
    "An obstacle may be either a stepping stone or a stumbling block.",
    "I hear and I forget. I see and I remember. I do and I understand.",
    "Difficulties are things that show a person what they are.",
    "Nature takes away any faculty that is not used.",
    "The secret of success is constancy to purpose.",
    "To succeed, we must first believe that we can.",
    "When you judge another, you do not define them, you define yourself.",
    "You give before you get.",
    "Make the most of yourself for that is all there is of you.",
    "Those who are free of resentful thoughts surely find peace.",
    "Think for yourselves and let others enjoy the privilege to do so too.",
    "The journey of a thousand miles begins with one step.",
    "I never worry about action, but only inaction.",
    "Take it easy � but take it.",
    "If you want a thing done well, do it yourself.",
    "Argue for your limitations, and sure enough they're yours.",
    "Wisdom is the supreme part of happiness.",
    "Every problem has a gift for you in its hands.",
    "A good plan today is better than a perfect plan tomorrow.",
    "If you have knowledge, let others light their candles in it.",
    "A stumble may prevent a fall.",
    "We aim above the mark to hit the mark.",
    "Friendship isn't a big thing. It's a million little things.",
    "The time you think you're missing, misses you too.",
    "To climb steep hills requires a slow pace at first.",
    "If the shoe doesn't fit, must we change the foot?",
    "Life is really simple, but we insist on making it complicated.",
    "Action will remove the doubts that theory cannot solve.",
    "The universe is made of stories, not atoms.",
    "A man is not where he lives but where he loves.",
    "You can't shake hands with a clenched fist.",
    "Great acts are made up of small deeds.",
    "The truth which has made us free will in the end make us glad also.",
    "Kind words do not cost much. Yet they accomplish much.",
    "Take rest; a field that has rested gives a bountiful crop.",
    "The years teach much which the days never know.",
    "Without some goals and some efforts to reach it, no man can live.",
    "We must not allow ourselves to become like the system we oppose.",
    "The most formidable weapon against errors of every kind is reason.",
    "In order to win, you must expect to win.",
    "A weed is no more than a flower in disguise.",
    "Beware of the half truth. You may have gotten hold of the wrong half.",
    "Imagination rules the world.",
    "The only real mistake is the one from which we learn nothing.",
    "Most folks are about as happy as they make up their minds to be.",
    "If you can't feed a hundred people, then feed just one.",
    "The heart has its reasons which reason knows not of.",
    "Be as you wish to seem.",
    "Do what you can. Want what you have. Be who you are.",
    "The less effort, the faster and more powerful you will be.",
    "The free man is he who does not fear to go to the end of his thought.",
    "People seldom notice old clothes if you wear a big smile.",
    "Rainbows apologize for angry skies.",
    "People may doubt what you say, but they will believe what you do.",
    "Never idealize others. They will never live up to your expectations.",
    "No act of kindness, no matter how small, is ever wasted.",
    "The best cure for the body is a quiet mind.",
    "A really great talent finds its happiness in execution.",
    "If you can dream it, you can do it.",
    "A man sees in the world what he carries in his heart.",
    "As we risk ourselves, we grow. Each new experience is a risk.",
    "I have never been hurt by anything I didn't say.",
    "Real success is finding your lifework in the work that you love.",
    "Sadness flies away on the wings of time.",
    "Why worry about tomorrow, when today is all we have?",
    "As you think, so shall you become.",
    "Most smiles are started by another smile.",
    "A man who doesn't trust himself can never really trust anyone else.",
    "Adversity causes some men to break, others to break records.",
    "Just trust yourself, then you will know how to live.",
    "A short saying oft contains much wisdom.",
    "The superior man is modest in his speech, but exceeds in his actions.",
    "Change your words. Change your world.",
    "Take it easy � but take it.",
    "The universe is transformation; our life is what our thoughts make it.",
    "Be your own hero, it's cheaper than a movie ticket.",
    "Goals are the fuel in the furnace of achievement.",
    "You are the only person on Earth who can use your ability.",
    "Reason and free inquiry are the only effectual agents against error.",
    "The best teacher is experience learned from failures.",
    "People may doubt what you say, but they will believe what you do.",
    "When you judge another, you do not define them, you define yourself.",
    "Speak low, if you speak love.",
    "We must not allow ourselves to become like the system we oppose.",
    "Change your thoughts, change your life!",
    "When performance exceeds ambition, the overlap is called success.",
    "To fly, we have to have resistance.",
    "All our knowledge has its origins in our perceptions.",
    "Gratitude is the fairest blossom which springs from the soul.",
    "A good rest is half the work.",
    "Tension is who you think you should be. Relaxation is who you are.",
    "Anything you really want, you can attain, if you really go after it.",
    "Let the beauty of what you love be what you do.",
    "The truth which has made us free will in the end make us glad also.",
    "Chaos is inherent in all compounded things. Strive on with diligence.",
    "Action is the foundational key to all success.",
    "We must not say every mistake is a foolish one.",
    "Ability will never catch up with the demand for it.",
    "Love is the master key that opens the gates of happiness.",
    "From error to error one discovers the entire truth.",
    "It isn't where you come from, it's where you're going that counts.",
    "I know but one freedom and that is the freedom of the mind.",
    "Our strength grows out of our weaknesses.",
    "You teach best what you most need to learn.",
    "If you can't explain it simply, you don't understand it well enough.",
    "Most smiles are started by another smile.",
    "Example has more followers than reason.",
    "Wherever a man turns he can find someone who needs him.",
    "Be kind whenever possible. It is always possible.",
    "It is impossible for a man to learn what he thinks he already knows.",
    "Success is getting what you want. Happiness is wanting what you get.",
    "Yeah we all shine on, like the moon, and the stars, and the sun.",
    "A person who never made a mistake never tried anything new.",
    "There is no way to prosperity, prosperity is the way.",
    "If I know what love is, it is because of you.",
    "The less effort, the faster and more powerful you will be.",
    "Every new day is another chance to change your life.",
    "It isn't where you come from, it's where you're going that counts.",
    "Talk doesn't cook rice.",
    "Gratitude is riches. Complaint is poverty.",
    "Rather than wishing for change, you first must be prepared to change.",
    "For everything that lives is holy, life delights in life.",
    "The best thing in every noble dream is the dreamer...",
    "The only real mistake is the one from which we learn nothing.",
    "Myths which are believed in tend to become true.",
    "Life isn't about finding yourself. Life is about creating yourself.",
    "Well done is better than well said.",
    "I hear and I forget. I see and I remember. I do and I understand.",
    "Life is a learning experience, only if you learn.",
    "Argue for your limitations, and sure enough they're yours.",
    "No man can succeed in a line of endeavor which he does not like.",
    "Love is just a word until someone comes along and gives it meaning.",
    "I know but one freedom and that is the freedom of the mind.",
    "Action will remove the doubts that theory cannot solve.",
    "Most folks are about as happy as they make up their minds to be.",
    "Kindness is the greatest wisdom.",
    "Our intention creates our reality.",
    "When the solution is simple, God is answering.",
    "The doors we open and close each day decide the lives we live.",
    "Life is just a chance to grow a soul.",
    "He who obtains has little. He who scatters has much.",
    "Those who are free of resentful thoughts surely find peace.",
    "The odds of hitting your target go up dramatically when you aim at it.",
    "Fear is a darkroom where negatives develop.",
    "From wonder into wonder existence opens.",
    "If you cannot do great things, do small things in a great way.",
    "I believe in one thing only, the power of human will.",
    "You can't choose up sides on a round world.",
    "Excellence is not a skill. It is an attitude.",
    "It's not what happens to you, but how you react to it that matters.",
    "Miracles come in moments. Be ready and willing.",
    "The deepest craving of human nature is the need to be appreciated.",
    "The free man is he who does not fear to go to the end of his thought.",
    "You can do it if you believe you can!",
    "There never was a good knife made of bad steel.",
    "Either I will find a way, or I will make one.",
    "Argue for your limitations, and sure enough theyre yours.",
    "Love is the master key that opens the gates of happiness.",
    "We lost because we told ourselves we lost.",
    "All the flowers of all the tomorrows are in the seeds of today.",
    "The difficulties of life are intended to make us better, not bitter.",
    "A stumble may prevent a fall.",
    "Nothing strengthens authority so much as silence.",
    "For success, attitude is equally as important as ability.",
    "He who knows that enough is enough will always have enough.",
    "The cautious seldom err.",
    "He who talks more is sooner exhausted.",
    "People may doubt what you say, but they will believe what you do.",
    "To succeed, we must first believe that we can.",
    "What you give is what you get.",
    "To avoid criticism, do nothing, say nothing, be nothing.",
    "Mistakes are always forgivable, if one has the courage to admit them.",
    "Success is determined by those whom prove the impossible, possible.",
    "Absence makes the heart grow fonder.",
    "Life is a succession of moments. To live each one is to succeed.",
    "All is flux; nothing stays still.",
    "Fear not for the future, weep not for the past.",
    "Wrinkles should merely indicate where smiles have been.",
    "The only way to have a friend is to be one.",
    "We choose our destiny in the way we treat others.",
    "Love is the master key that opens the gates of happiness.",
    "Wisdom is the supreme part of happiness.",
    "Most people are about as happy as they make up their minds to be",
    "The cause is hidden. The effect is visible to all.",
    "I begin with an idea and then it becomes something else.",
    "All is flux; nothing stays still.",
    "Silence is a fence around wisdom.",
    "Better than a thousand hollow words, is one word that brings peace.",
    "If you can dream it, you can do it.",
    "I may not know everything, but everything is not known yet anyway.",
    "From wonder into wonder existence opens.",
    "You really can change the world if you care enough.",
    "The years teach much which the days never know.",
    "You can observe a lot just by watching.",
    "The best way out is always through.",
    "All things change; nothing perishes.",
    "You only lose what you cling to.",
    "The only real failure in life is not to be true to the best one knows.",
    "Just as much as we see in others we have in ourselves.",
    "What you are is what you have been. What you�ll be is what you do now.",
    "If there is no struggle, there is no progress.",
    "The cure for boredom is curiosity. There is no cure for curiosity.",
    "To bring anything into your life, imagine that it's already there.",
    "It's not what happens to you, but how you react to it that matters.",
    "Never put off till tomorrow what you can do today.",
    "It isn't where you come from, it's where you're going that counts.",
    "Experience keeps a dear school, but fools will learn in no other.",
    "Every problem has a gift for you in its hands.",
    "No one can make you feel inferior without your consent.",
    "The only way to have a friend is to be one.",
    "There never was a good knife made of bad steel.",
    "Beauty is not in the face; beauty is a light in the heart.",
    "The future is completely open, and we are writing it moment to moment.",
    "Music in the soul can be heard by the universe.",
    "What we see depends mainly on what we look for.",
    "It does not matter how slowly you go as long as you do not stop.",
    "To hell with circumstances; I create opportunities.",
    "Every problem has a gift for you in its hands.",
    "It's easier to see the mistakes on someone else's paper.",
    "No day in which you learn something is a complete loss.",
    "He who has imagination without learning has wings but no feet.",
    "When in doubt, tell the truth.",
    "The world is always in movement.",
    "A man sees in the world what he carries in his heart.",
    "Learning is finding out what you already know.",
    "I have never been hurt by anything I didn't say.",
    "What you give is what you get.",
    "The world is always in movement.",
    "The future is completely open, and we are writing it moment to moment.",
    "Nothing ever goes away until it has taught us what we need to know.",
    "Myths which are believed in tend to become true.",
    "Go put your creed into the deed. Nor speak with double tongue.",
    "Those who cannot learn from history are doomed to repeat it.",
    "It isn't where you come from, it's where you're going that counts.",
    "Keep yourself to the sunshine and you cannot see the shadow.",
    "We never live; we are always in the expectation of living.",
    "To enjoy life, we must touch much of it lightly.",
    "If you cannot do great things, do small things in a great way.",
    "If one does not know to which port is sailing, no wind is favorable.",
    "Smile, breathe and go slowly.",
    "Wherever a man turns he can find someone who needs him.",
    "Stay away from what might have been and look at what will be.",
    "An ounce of emotion is equal to a ton of facts.",
    "If a man does his best, what else is there?",
    "Only when we are no longer afraid do we begin to live.",
    "Our strength grows out of our weaknesses.",
    "When in doubt, tell the truth.",
    "We must become the change we want to see.",
    "Great is the art of beginning, but greater is the art of ending.",
    "Smile, breathe and go slowly.",
    "Time is the most valuable thing a man can spend.",
    "Chaos and Order are not enemies, only opposites.",
    "The day you decide to do it is your lucky day.",
    "You give before you get.",
    "Keep your eyes on the stars and your feet on the ground.",
    "Argue for your limitations, and sure enough theyre yours.",
    "The only limit to your impact is your imagination and commitment.",
    "You must welcome change as the rule but not as your ruler.",
    "If you correct your mind, the rest of your life will fall into place.",
    "Trouble is only opportunity in work clothes.",
    "You're never a loser until you quit trying.",
    "If the shoe doesn't fit, must we change the foot?",
    "Nothing will work unless you do.",
    "Doing nothing is better than being busy doing nothing.",
    "I know but one freedom and that is the freedom of the mind.",
    "We know what we are, but know not what we may be.",
    "They must often change, who would be constant in happiness or wisdom.",
    "If you want a thing done well, do it yourself.",
    "Patience is the companion of wisdom.",
    "If you cannot be silent be brilliant and thoughtful.",
    "A rolling stone gathers no moss.",
    "To fly, we have to have resistance.",
    "Never mistake activity for achievement.",
    "The bird of paradise alights only upon the hand that does not grasp.",
    "Why worry about tomorrow, when today is all we have?",
    "Those who are free of resentful thoughts surely find peace.",
    "Pick battles big enough to matter, small enough to win.",
    "The ladder of success is never crowded at the top.",
    "Love is the flower you've got to let grow.",
    "Trust yourself. You know more than you think you do.",
    "We must embrace pain and burn it as fuel for our journey.",
    "He who is fixed to a star does not change his mind.",
    "The superior man is modest in his speech, but exceeds in his actions.",
    "You can't trust without risk but neither can you live in a cocoon.",
    "Be a good listener. Your ears will never get you in trouble.",
    "Do what you can. Want what you have. Be who you are.",
    "Think for yourselves and let others enjoy the privilege to do so too.",
    "Things do not change, we change.",
    "They can do all because they think they can.",
    "To be tested is good. The challenged life may be the best therapist.",
    "Act as if what you do makes a difference. It does.",
    "Our intention creates our reality.",
    "A goal is a dream with a deadline.",
    "Nothing is a waste of time if you use the experience wisely.",
    "The years teach much which the days never know.",
    "Life is a learning experience, only if you learn.",
    "Don't settle for a relationship that won't let you be yourself.",
    "If we did the things we are capable of, we would astound ourselves.",
    "The only real valuable thing is intuition.",
    "You always succeed in producing a result.",
    "A prudent question is one half of wisdom.",
    "Knowing is not enough; we must apply!",
    "Don't wait. The time will never be just right.",
    "Mountains cannot be surmounted except by winding paths.",
    "If you surrender to the wind, you can ride it.",
    "All know the way; few actually walk it.",
    "Those who are free of resentful thoughts surely find peace.",
    "No is easier to do. Yes is easier to say.",
    "Forgiveness does not change the past, but it does enlarge the future.",
    "A beautiful thing is never perfect.",
    "Keep your eyes on the stars and your feet on the ground.",
    "From error to error one discovers the entire truth.",
    "I believe that every person is born with talent.",
    "Doing nothing is better than being busy doing nothing.",
    "To be wronged is nothing unless you continue to remember it.",
    "The future is completely open, and we are writing it moment to moment.",
    "Victory belongs to the most persevering.",
    "A house divided against itself cannot stand.",
    "Absence makes the heart grow fonder.",
    "We must become the change we want to see.",
    "Experience is simply the name we give our mistakes.",
    "What you are is what you have been. What you�ll be is what you do now.",
    "Watch the little things; a small leak will sink a great ship.",
    "Self-complacency is fatal to progress.",
    "The journey of a thousand miles begins with one step.",
    "All achievements, all earned riches, have their beginning in an idea.",
    "Life is what happens to you while you're busy making other plans.",
    "Peace begins with a smile.",
    "Kindness is the golden chain by which society is bound together.",
    "We are Divine enough to ask and we are important enough to receive.",
    "Three things cannot be long hidden: the sun, the moon, and the truth.",
    "When you lose, don't lose the lesson.",
    "Worry gives a small thing a big shadow.",
    "My reputation grows with every failure.",
    "A good plan today is better than a perfect plan tomorrow.",
    "The awareness of our own strength makes us modest.",
    "A good rest is half the work.",
    "He who conquers others is strong; He who conquers himself is mighty.",
    "Patience is the companion of wisdom.",
    "It is not in the stars to hold our destiny but in ourselves.",
    "Weve got to have a dream if we are going to make a dream come true.",
    "Follow your instincts. That is where true wisdom manifests itself.",
    "A man should look for what is, and not for what he thinks should be.",
    "Those that know, do. Those that understand, teach.",
    "To be upset over what you don't have is to waste what you do have.",
    "When in doubt, tell the truth.",
    "Think how hard physics would be if particles could think.",
    "They can do all because they think they can.",
    "I believe that every person is born with talent.",
    "There are people who have money and people who are rich.",
    "The more you know yourself, the more you forgive yourself.",
    "Kind words will unlock an iron door.",
    "To get the full value of joy you must have someone to divide it with.",
    "Where there is great love, there are always miracles.",
    "To see things in the seed, that is genius.",
    "We must become the change we want to see.",
    "I have often regretted my speech, never my silence.",
    "If I know what love is, it is because of you.",
    "If you have knowledge, let others light their candles in it.",
    "What you fear is that which requires action to overcome.",
    "I will prepare and some day my chance will come.",
    "Think as a wise man but communicate in the language of the people.",
    "Imagination rules the world.",
    "Excellence is to do a common thing in an uncommon way.",
    "Be kind whenever possible. It is always possible.",
    "What we see depends mainly on what we look for.",
    "Sadness flies away on the wings of time.",
    "The winds and waves are always on the side of the ablest navigators.",
    "Victory belongs to the most persevering.",
    "I believe that every person is born with talent.",
    "It is the quality of our work which will please God, not the quantity.",
]

tr_biyografiler = [
    "Acı geçer ama güzellik kalır.",
    "Acıyı kucaklamalı ve yolculuğumuz için yakıt olarak yakmalıyız.",
    "Affetmek geçmişi değiştirmez ama geleceği genişletir.",
    "Aktiviteyi asla başarı ile karıştırmayın.",
    "Akıl ve özgür araştırma, hataya karşı tek etkili ajanlardır.",
    "Akıllı bir adam gibi düşün ama insanların dilinden konuş.",
    "Allah sana bir yüz vermiş, sen kendine başka bir yüz vermişsin.",
    "Almadan önce verirsin.",
    "Anlam, başladığınız şey değil, bitirdiğiniz şeydir.",
    "Arkadaşlık büyük bir şey değil. Milyonlarca küçük şey.",
    "Arkana bakma. Bir şeyler sana kazandırıyor olabilir.",
    "Artık denememek dışında başarısızlık yoktur.",
    "Asla asla asla vazgeçme.",
    "Asla hareketi eylemle karıştırmayın.",
    "Asla yapabileceğinden fazlasını vaat etme.",
    "Asla yaşamıyoruz, hep yaşamanın beklentisi içindeyiz.",
    "Ay için ateş et. Iskalarsan bile yıldızların arasına düşersin.",
    "Ayak, yeri hissettiğinde ayağı hisseder.",
    "Ayakkabı uymazsa ayağı değiştirmeli miyiz?",
    "Ayaklarınızı doğru yere koyduğunuzdan emin olun, sonra sağlam durun.",
    "Aynı anda hem minnettar hem de depresif hissetmek imkansızdır.",
    "Açık zihinler açık kapılara yol açar.",
    "Aşk konuşuyorsan alçak sesle konuş.",
    "Aşk, biri gelip ona anlam verene kadar sadece bir kelimedir.",
    "Aşk, büyümesine izin vermen gereken çiçektir.",
    "Aşk, mutluluğun kapılarını açan ana anahtardır.",
    "Aşkın ne olduğunu biliyorsam, senin sayendedir.",
    "Bahar, yeniden doğuş ve yeni hayatın gerçekleşmesi için bir zamandır.",
    "Barış içeriden gelir. Onu dışarıda aramayın.",
    "Barış, bir gülücükle başlar.",
    "Basitçe açıklayamıyorsan, yeterince iyi anlamamışsın demektir.",
    "Bazen en büyük cesaret eylemi küçük bir cesarettir.",
    "Bazıları mutluluğun peşinden koşar, diğerleri onu yaratır.",
    "Baş dönmesi olan, dünyanın döndüğünü zanneder.",
    "Başarı için tutum, yetenek kadar önemlidir.",
    "Başarı merdiveni asla zirvede kalabalık değildir.",
    "Başarı, istediğini elde etmektir. Mutluluk, elde ettiğini istemektir.",
    "Başarılı olmak için önce yapabileceğimize inanmalıyız.",
    "Başarının formülü: söz vermek ve teslim etmek.",
    "Başarının ilk sırrı özgüvendir.",
    "Başarının sırrı amaca bağlı kalmaktır.",
    "Başarının önündeki en büyük engel başarısızlık korkusudur.",
    "Başarısızlık olarak düşünme. Zamana bağlı bir başarı olarak düşün.",
    "Başarısızlık yoktur, sadece deneyimler ve onlara tepkileriniz vardır.",
    "Başarısızlık yoktur. Sadece deneyimler ve onlara tepkileriniz.",
    "Başarısızlığın bir kişi değil, bir olay olduğunu unutmayın.",
    "Başarıya doğru ilerlemek başarısız olur.",
    "Başarıya giden yol, büyük ve kararlı adımlar atmaktır.",
    "Başkalarına karşı nazik olmak istiyorsan önce kendine karşı nazik ol.",
    "Başkalarında gördüğümüz kadar kendimizde de vardır.",
    "Başkalarını bilen bilgedir. Kendini bilen aydındır.",
    "Başkalarını yenen güçlüdür, kendini yenen güçlüdür.",
    "Başkasının kağıdındaki hataları görmek daha kolay.",
    "Başlangıç her zaman bugündür.",
    "Be a good listener. Your ears will never get you in trouble.",
    "Be sure you put your feet in the right place, then stand firm.",
    "Be the change that you want to see in the world.",
    "Be your own hero, it's cheaper than a movie ticket.",
    "Beauty is not in the face; beauty is a light in the heart.",
    "Begin, be bold, and venture to be wise.",
    "Bekleme. Zaman asla doğru olmayacak.",
    "Better than a thousand hollow words, is one word that brings peace.",
    "Beware of the half truth. You may have gotten hold of the wrong half.",
    "Bilen konuşmaz. Konuşan bilmez.",
    "Bilen yapar. Anlayan öğretir.",
    "Bilgelik meraktan doğar.",
    "Bilgelik, mutluluğun en üst kısmıdır.",
    "Bilgi, yalnızca gerçeğe değil, aynı zamanda yanılgıya da dayanır.",
    "Bilim organize bilgidir. Bilgelik organize yaşamdır.",
    "Bilmek yetmez, uygulamalıyız!",
    "Bin boş kelimeden daha iyidir, barış getiren bir kelimedir.",
    "Bin boş sözden daha iyidir, barış getiren bir kelimedir.",
    "Bin millik yolculuk bir adımla başlar.",
    "Bir adam bir şey aradığı sürece yaşlı değildir.",
    "Bir adam doğuştan değil, eylemleriyle büyüktür.",
    "Bir adam elinden gelenin en iyisini yaparsa, başka ne var?",
    "Bir adam, olması gerektiğini düşündüğü şeyi değil, olanı aramalı.",
    "Bir adamın hayalleri, onun büyüklüğünün bir göstergesidir.",
    "Bir arkadaştan gelen her hediye, mutluluğunuz için bir dilektir.",
    "Bir bugün iki yarına bedeldir.",
    "Bir engel, bir basamak ya da tökezleme taşı olabilir.",
    "Bir eylem adamı gibi düşün, bir düşünce adamı gibi davran.",
    "Bir fikirle başlarım ve sonra başka bir şeye dönüşür.",
    "Bir gülümsemenin ardından gün her zaman daha parlak görünür.",
    "Bir günlük endişe, bir günlük çalışmadan daha yorucudur.",
    "Bir hayali gerçekleştireceksek, bir hayalimiz olmalı.",
    "Bir konuyu yarım bilmektense cahil olmak daha iyidir.",
    "Bir noktaya varmak, diğerinin başlangıç noktasıdır.",
    "Bir ot, kılık değiştirmiş bir çiçekten başka bir şey değildir.",
    "Bir telaş içinde kalırsan kaymazsın.",
    "Bir testi damla damla doldurur.",
    "Bir tökezleme düşmeyi önleyebilir.",
    "Bir yanlışı hatırlamak, zihne yük taşımak gibidir.",
    "Bir yıldıza sabitlenen, fikrini değiştirmez.",
    "Bir şey öğrendiğin hiçbir gün tam bir kayıp değildir.",
    "Bir şeyin iyi yapılmasını istiyorsan, kendin yap.",
    "Biraz delilik dokunuşu olmadan büyük bir dahi yoktur.",
    "Biraz için şükredin, çok şey bulacaksınız.",
    "Birbirinizi boğmayın. Kimse gölgede büyüyemez.",
    "Biri ancak sen söylersen özeldir.",
    "Biri için bir lamba yakarsan, yolunuzu da aydınlatır.",
    "Birinin olabileceği gibi olmayı istemek, hayatın amacıdır.",
    "Birçok mağlubiyetle karşılaşabiliriz ama mağlup olmamalıyız.",
    "Bitti diye ağlama. Olduğu için gülümse.",
    "Biz kendi kaderimizi yaratırız ve onlara kader deriz.",
    "Bize bilmemiz gerekeni öğretmedikçe hiçbir şey ortadan kaybolmaz.",
    "Bizi hür iradeye kavuşturan hakikat, sonunda bizleri de sevindirir.",
    "Bizler isteyebilecek kadar ilahiyiz ve alacak kadar önemliyiz.",
    "Boşa harcanan zamandan daha büyük bir zarar yoktur.",
    "Bugün başlamayan, yarın asla bitmez.",
    "Bugün yapabileceğin işi asla yarına bırakma.",
    "Bugün, dün için endişelendiğimiz yarındır.",
    "Bugün, dün için endişelendiğin yarındır.",
    "Bugünkü iyi bir plan, yarınki mükemmel bir plandan daha iyidir.",
    "Bunu yapmaya karar verdiğin gün senin şanslı günündür.",
    "Bütün bilgilerimizin kökenleri algılarımızdadır.",
    "Bütün büyük başarılar zaman gerektirir.",
    "Bütün yarınların tüm çiçekleri bugünün tohumlarındadır.",
    "Büyük aşkın olduğu yerde, her zaman mucizeler vardır.",
    "Büyük fikirler genellikle vasat beyinlerden şiddetli muhalefet alır.",
    "Büyük fırsatınız şu an bulunduğunuz yerde olabilir.",
    "Büyük işler küçük işlerden oluşur.",
    "Büyük olmak, yanlış anlaşılmaktır.",
    "Büyük yetenek, mutluluğu uygulamada bulur.",
    "Büyük şeyler başarmış tüm insanlar büyük hayalperestlerdir.",
    "Büyük şeyler yapamıyorsanız, küçük şeyleri harika bir şekilde yapın.",
    "Büyümek ve gerçekte olduğunuz kişi olmak cesaret ister.",
    "Büyümenin kendisi mutluluk tohumu içerir.",
    "Cehalet asla bir soruyu çözmez.",
    "Cennet kuşu ancak kavramayan ele konar.",
    "Cesaret olmadan bilgelik meyve vermez.",
    "Cesaret, coşkuyu kaybetmeden başarısızlıktan başarısızlığa gitmektir.",
    "Change your words. Change your world.",
    "Chaos and Order are not enemies, only opposites.",
    "Chaos is inherent in all compounded things. Strive on with diligence.",
    "Daha çok konuşan daha çabuk tükenir.",
    "Daima başkalarının kusurlarına değil, iyiliklerine dikkat edin.",
    "Dalgaları durduramazsın ama sörf yapmayı öğrenebilirsin.",
    "Dans eden bir yıldız doğurmak için ruhunda kaosa ihtiyacın var.",
    "Dayanılması zor olan şeyleri hatırlamak tatlıdır.",
    "Dağlar, dolambaçlı yollar dışında aşılmaz.",
    "Dene ve başarısız ol, ama denemekten vazgeçme.",
    "Denemeyi bırakana kadar asla kaybeden değilsin.",
    "Deneyen için imkansız diye bir şey yoktur.",
    "Deneyim, düşünmekle, hayal kurmakla değil, ancak yaparak kazanılır.",
    "Değişimi istemek yerine, önce değişime hazır olmalısınız.",
    "Değişimi kural olarak kabul etmelisin ama hükümdarın olarak değil.",
    "Dik tepelere tırmanmak için önce yavaş bir tempo gerekir.",
    "Dikkat edin: Aramadığınızı bulamazsınız.",
    "Dili ağır, gözü hızlı ol.",
    "Dinlenin; dinlenmiş tarla bol ürün verir.",
    "Do good by stealth, and blush to find it fame.",
    "Do not wait for leaders; do it alone, person to person.",
    "Do what you can. Want what you have. Be who you are.",
    "Don't settle for a relationship that won't let you be yourself.",
    "Doğa kullanılmayan her yeteneği alır götürür.",
    "Doğa, her zaman ve asla aynı olmayan değişken bir buluttur.",
    "Doğadaki her şeyde olağanüstü bir şey vardır.",
    "Doğru değilse yapma, doğru değilse söyleme.",
    "Durmadan, tek bir amacı takip etmek: Başarının sırrı vardır.",
    "Durmadığınız sürece ne kadar yavaş gittiğinizin bir önemi yoktur.",
    "Durumumuz yeni olduğu için yeniden düşünmeli ve hareket etmeliyiz.",
    "Dün iç saha koşuları bugünün maçlarını kazanmıyor.",
    "Dün mücadele etmeye cüret ettim. Bugün kazanmaya cüret ediyorum.",
    "Dünden öğren, bugünü yaşa, yarın için umut et.",
    "Dünya bir kitaptır ve seyahat etmeyenler sadece bir sayfasını okurlar.",
    "Dünya her zaman hareket halindedir.",
    "Dünya senin başına gelmez, senden olur.",
    "Dünya, hayal gücü için bir tuvalden başka bir şey değildir.",
    "Dünyada görmek istediğin değişimin kendisi ol.",
    "Dünyanın sonsuz gizeminin anlaşılabilirliği olduğu söylenebilir.",
    "Dünyayı yanlış okuyup bizi aldattığını söylüyoruz.",
    "Düzeltme çok şey yapar, ancak teşvik daha fazlasını yapar.",
    "Düşmanlarımı dost edindiğimde onları yok ederim.",
    "Düştüğünüzden bir kez daha kalkarsanız, atlatırsınız.",
    "Düşünce çiçektir; dil tomurcuktur; eylem ise arkasındaki meyvedir.",
    "Düşüncede olduğun gibi, eylemde de harika ol.",
    "Düşüncelerini değiştir, hayatını değiştir!",
    "Düşündüğün gibi olacaksın.",
    "Düşünmeyi bırakırken, çoğu zaman fırsatımızı kaçırırız.",
    "Düşünüyorum ve bu kadarım.",
    "Dışarı bakan rüya görür; içeriye bakan uyanır.",
    "Dışarı çıkmaktan korkmayın. Meyvenin olduğu yer orası.",
    "Either I will find a way, or I will make one.",
    "Elenin azı vardır. Dağıtanın çok vardır.",
    "Elinden geleni yap. Sahip olduğun şeyi iste. Kendin ol.",
    "En basit şeyler genellikle en doğrudur.",
    "En başarılı insanlar, B planında iyi olanlardır.",
    "En bilge adamlar kendi yönlerini takip ederler.",
    "En gerçek bilgelik, kararlı bir kararlılıktır.",
    "En güçlü iki savaşçı sabır ve zamandır.",
    "En güçlü, kendi gücüne sahip olandır.",
    "En iyi yol dosdoğru gidendir.",
    "En iyi öğretmen, başarısızlıklardan öğrenilen deneyimdir.",
    "En kısa cevap yapmaktır.",
    "Endişe genellikle küçük bir şeye büyük bir gölge verir.",
    "Endişe küçük bir şeye büyük bir gölge verir.",
    "Er ya da geç kazananlar, yapabileceklerini düşünenlerdir.",
    "Erdem eken, onur biçer.",
    "Etkinizin tek sınırı hayal gücünüz ve bağlılığınızdır.",
    "Etrafta kimse yokken gülümsersen, gerçekten ciddisindir.",
    "Every gift from a friend is a wish for your happiness.",
    "Evet, hepimiz ay, yıldızlar ve güneş gibi parlıyoruz.",
    "Evren atomlardan değil, hikayelerden oluşur.",
    "Evren bir dönüşümdür; hayatımız düşüncelerimizin onu yaptığı şeydir.",
    "Example has more followers than reason.",
    "Excellence is not a skill. It is an attitude.",
    "Excellence is to do a common thing in an uncommon way.",
    "Experience keeps a dear school, but fools will learn in no other.",
    "Eylem hakkında asla endişelenmem, sadece eylemsizlik.",
    "Eylem, teorinin çözemediği şüpheleri ortadan kaldıracaktır.",
    "Eylem, tüm başarının temel anahtarıdır.",
    "Eğer sonuna kadar gitmiyorsan, neden gidiyorsun?",
    "Fear not for the future, weep not for the past.",
    "Fethedilmekten korkan, yenilgiden emindir.",
    "Fikirler, tüm servetlerin başlangıç noktalarıdır.",
    "Fikrini düzeltirsen, hayatının geri kalanı yerine oturacaktır.",
    "For everything that lives is holy, life delights in life.",
    "For success, attitude is equally as important as ability.",
    "Forgiveness does not change the past, but it does enlarge the future.",
    "From wonder into wonder existence opens.",
    "Gelecek için korkma, geçmiş için ağlama.",
    "Gelecek tamamen açık ve onu an be an yazıyoruz.",
    "Gelecek, hayallerinin güzelliğine inananlarındır.",
    "Geleceği hiç düşünmüyorum. Çok yakında geliyor.",
    "Geleceğin birçok şeye bağlı ama en çok sana bağlı.",
    "Geleceğinizi emin ellere, kendinizinkilere bırakın.",
    "Geleceğinizi tahmin etmenin en iyi yolu onu yaratmaktır.",
    "Gençliğinin hayallerine sadık kal.",
    "Gerçek başarı, sevdiğiniz işte yaşam çabanızı bulmaktır.",
    "Gerçek güçlüdür ve galip gelir.",
    "Gerçek, genellikle iftiraya karşı en iyi savunmadır.",
    "Gerçek, hayal gücüne çok şey bırakır.",
    "Gerçek, ideale uymaz, onu doğrular.",
    "Gerçeklik, çok kalıcı olmasına rağmen yalnızca bir yanılsamadır.",
    "Gerçekten büyük bir yetenek, mutluluğunu icrada bulur.",
    "Gerçekten değerli olan tek şey sezgidir.",
    "Gerçeği sadece akılla değil, kalple de biliyoruz.",
    "Geçmiş ne kadar zor olursa olsun, her zaman yeniden başlayabilirsin.",
    "Geçmişi araştır, eğer geleceği tahmin edeceksen.",
    "Git akideni amelin içine koy. Ne de iki dille konuş.",
    "Gizlilikle iyilik yapın ve şöhret bulmak için kızarın.",
    "Go put your creed into the deed. Nor speak with double tongue.",
    "Gratitude is riches. Complaint is poverty.",
    "Gratitude is the fairest blossom which springs from the soul.",
    "Great acts are made up of small deeds.",
    "Great is the art of beginning, but greater is the art of ending.",
    "Gökkuşağı kızgın gökyüzü için özür diler.",
    "Gökkuşağı oluşturmak için hem güneş ışığı hem de yağmur gerekir.",
    "Gördüklerimiz esas olarak aradığımız şeydir.",
    "Gördüğün şey, aradığın şeye bağlıdır.",
    "Görmek istediğimiz değişimin kendisi olmalıyız.",
    "Görünmek istediğin gibi ol.",
    "Göz, yalnızca zihnin kavramaya hazır olduğunu görür.",
    "Gözlerin yıldızlarda ve ayakların yerde olsun.",
    "Göğsüne git: Orayı çal ve kalbine ne bildiğini sor.",
    "Gücümüz zayıflıklarımızdan doğar.",
    "Gücümüzün farkında olmak bizi alçakgönüllü yapar.",
    "Gücünüzden şüphe ettiğinizde, şüphenize güç vermiş olursunuz.",
    "Gülümse nefes al ve yavaşça git.",
    "Gün mübarektir, içinde huzur bul.",
    "Güneş ışığına kendini tut, gölgeyi göremezsin.",
    "Güvensizliğimiz çok pahalı.",
    "Güzel bir anın bedelini ödemenin en iyi yolu, onun tadını çıkarmaktır.",
    "Güzel bir şey asla mükemmel olmaz.",
    "Güzel sözler çok pahalıya mal olmaz. Yine de çok şey başarır.",
    "Güzellik yüzde değil, güzellik kalpte bir ışıktır.",
    "Hafıza tüm bilgeliğin anasıdır.",
    "Harcamaktan keyif aldığın zaman, israf edilmiş zaman değildir.",
    "Harika bir şey yapın, insanlar onu taklit edebilir.",
    "Hata yapma özgürlüğünü çağrıştırmıyorsa, özgürlük sahip olmaya değmez.",
    "Hata, ilerlediğimiz disiplindir.",
    "Hatadan hataya, insan tüm gerçeği keşfeder.",
    "Hatırlamaya devam etmedikçe haksızlığa uğramak bir şey değildir.",
    "Hatırlamaya devam etmedikçe yanılmak hiçbir şeydir.",
    "Hayal edebildiğin her şey gerçektir.",
    "Hayal edebiliyorsan, yapabilirsin.",
    "Hayal etmekten fazlasını yapın: çalışın.",
    "Hayal gücü dünyayı yönetir.",
    "Hayal gücü uçabilecek en yüksek uçurtmadır.",
    "Hayat %10 başınıza gelenler ve %90'ı ona nasıl tepki verdiğinizdir.",
    "Hayat bir ilerlemedir, bir durak değil.",
    "Hayat bir süreçtir. Biz bir süreciz. Evren bir süreçtir.",
    "Hayat bir öğrenme deneyimidir, ancak öğrenirsen.",
    "Hayat değişimdir. Büyüme isteğe bağlıdır. Akıllıca seçin.",
    "Hayat hakkında söyleyebileceğim tek şey, Aman Tanrım, tadını çıkar!",
    "Hayat harekettir - nefes alırız, yeriz, yürürüz, hareket ederiz!",
    "Hayat insanın cesareti oranında küçülür ya da genişler.",
    "Hayat sadece bir ruhu büyütmek için bir şanstır.",
    "Hayat, anlaşılması için yaşanması gereken bir dersler dizisidir.",
    "Hayat, balı aşk olan çiçektir.",
    "Hayat, onu ne yaparsan odur. Her zaman vardı, her zaman olacak.",
    "Hayat, sen başka planlar yaparken başına gelenlerdir.",
    "Hayatlarımız yaptığımız seçimlerin toplamıdır.",
    "Hayatta her şey şanstır.",
    "Hayatta korkulacak hiçbir şey yoktur. Sadece anlaşılmak içindir.",
    "Hayatta tek bir mutluluk vardır, sevmek ve sevilmek.",
    "Hayattaki tek gerçek başarısızlık, en iyi bildiğine sadık olmamaktır.",
    "Hayattan zevk almak için çoğuna hafifçe dokunmalıyız.",
    "Hayatın zorlukları bizi daha iyi hale getirmek içindir, acı değil.",
    "Hayır yapmak daha kolay. Evet demek daha kolay.",
    "He who has imagination without learning has wings but no feet.",
    "He who knows himself is enlightened.",
    "He who knows others is wise. He who knows himself is enlightened.",
    "He who knows that enough is enough will always have enough.",
    "He who knows, does not speak. He who speaks, does not know.",
    "He who lives in harmony with himself lives in harmony with the world.",
    "Hedef, son teslim tarihi olan bir rüyadır.",
    "Hedefe vardığında geri dönme.",
    "Hedefe yaklaştıkça zorluklar artar.",
    "Hedefler, başarı fırınındaki yakıttır.",
    "Hedeflerinizi yüksek tutun ve oraya ulaşana kadar durmayın.",
    "Hepimiz bir şeyiz, ama hiçbirimiz her şey değiliz.",
    "Hepsi yolu bilir; çok azı gerçekten yürür.",
    "Her asil rüyadaki en güzel şey, hayalperesttir...",
    "Her derdin elinde sana bir armağanı vardır.",
    "Her gün açıp kapattığımız kapılar yaşadığımız hayatları belirler.",
    "Her gün iyi olmayabilir ama her günün içinde iyi bir şey vardır.",
    "Her gün kendi hediyelerini sunar.",
    "Her gün seni korkutan bir şey yap.",
    "Her hata aptalcadır dememeliyiz.",
    "Her insan kendi sağlığının veya hastalığının yaratıcısıdır.",
    "Her insan ölür. Her insan gerçekten yaşamaz.",
    "Her insanın yetenekle doğduğuna inanıyorum.",
    "Her türlü hataya karşı en güçlü silah akıldır.",
    "Her yeni gün, hayatınızı değiştirmek için başka bir şanstır.",
    "Her zaman bir sonuç üretmeyi başarırsın.",
    "Her zaman birisi olmak istedim ama daha spesifik olmalıydım.",
    "Her zaman kaybeden, ödülü alan tek kişidir.",
    "Her zaman seni işe alan insanlardan daha akıllı ol.",
    "Her zorlukta daima zafer tohumunu arayın.",
    "Her zorluğun ortasında fırsat yatar.",
    "Her şey akıştır; hiçbir şey hareketsiz kalmaz.",
    "Her şey değişir; hiçbir şey yok olmaz.",
    "Her şeyde değişiklik tatlıdır.",
    "Her şeyi bilmiyor olabilirim ama yine de her şey henüz bilinmiyor.",
    "Her şeyi bir anda yapamayız ama bir şeyi aynı anda yapabiliriz.",
    "Her şeyin bir güzelliği vardır ama bunu herkes göremez.",
    "Herkes aynı dilde gülümser.",
    "Herkes tarih yazabilir. Sadece büyük bir adam onu yazabilir.",
    "Herkesi sev, birkaçına güven, hiçbirine yanlış yapma.",
    "Herkesin aynı düşündüğü yerde kimse fazla düşünmez.",
    "Hiç güzel olmayan gülen bir yüz görmedim.",
    "Hiç hata yapmayan insan, asla yeni bir şey denemez.",
    "Hiç kimse her şeyi yapamaz ama herkes bir şeyler yapabilir.",
    "Hiç kimse hoşlanmadığı bir işte başarılı olamaz.",
    "Hiç kimse sizin rızanız olmadan sizi aşağılık hissettiremez.",
    "Hiç kimse tesadüfen bilge olmamıştır.",
    "Hiç kimse vermekle yoksullaşmamıştır.",
    "Hiçbir mazeret sizi sorumluluğu kabul etmekten kurtaramaz.",
    "Hiçbir zaman büyük bir şey coşku olmadan elde edilmemiştir.",
    "Hiçbir şey kaygıyı eylemden daha hızlı azaltamaz.",
    "Hiçbir şey otoriteyi sessizlik kadar güçlendiremez.",
    "Hiçbir şey yapmamak, hiçbir şey yapmamakla meşgul olmaktan iyidir.",
    "Hiçbir şeyi olmayan, hiçbir şey kaybedemez.",
    "I begin with an idea and then it becomes something else.",
    "I have never been hurt by anything I didn't say.",
    "I have no special talent. I am only passionately curious.",
    "I hear and I forget. I see and I remember. I do and I understand.",
    "I know but one freedom and that is the freedom of the mind.",
    "I may not know everything, but everything is not known yet anyway.",
    "I never worry about action, but only inaction.",
    "I will prepare and some day my chance will come.",
    "If I know what love is, it is because of you.",
    "If you can't explain it simply, you don't understand it well enough.",
    "If you can't feed a hundred people, then feed just one.",
    "If you come to a fork in the road, take it.",
    "If you find yourself in a hole, the first thing to do is stop digging.",
    "If you have knowledge, let others light their candles in it.",
    "If you kick a stone in anger, you'll hurt your own foot.",
    "If you want a thing done well, do it yourself.",
    "Impossibilities are merely things which we have not yet learned.",
    "In seed time learn, in harvest teach, in winter enjoy.",
    "In skating over thin ice our safety is in our speed.",
    "In the middle of every difficulty lies opportunity.",
    "It is impossible for a man to learn what he thinks he already knows.",
    "It is not in the stars to hold our destiny but in ourselves.",
    "It is the quality of our work which will please God, not the quantity.",
    "It isn't where you come from, it's where you're going that counts.",
    "It's not what happens to you, but how you react to it that matters.",
    "Just as much as we see in others we have in ourselves.",
    "Just trust yourself, then you will know how to live.",
    "Kabul etme cesareti varsa, hatalar her zaman affedilebilir.",
    "Kader bize bir limon verdiğinde, limonata yapmaya çalışalım.",
    "Kader senin elinde, başka kimsenin değil",
    "Kaderimizi başkalarına nasıl davrandığımıza göre seçeriz.",
    "Kaderin senin karar anlarında şekillenir.",
    "Kalbin geçmiş başarısızlıklarla doluysa bahar olamaz.",
    "Kalbin, aklın bilmediği sebepleri vardır.",
    "Kalbin, beynin bilmediği gözleri vardır.",
    "Kalite, kimse bakmadığında doğru olanı yapmaktır.",
    "Kaos tüm bileşik şeylerin doğasında vardır. Gayretle çalışın.",
    "Kaos ve Düzen düşman değil, sadece zıtlardır.",
    "Karakter kendini hayatın akışı içinde geliştirir.",
    "Karar, özgür olma cesaretinden kaynaklanan bir risktir.",
    "Kararlarınıza bağlı kalın, ancak yaklaşımınızda esnek kalın.",
    "Karşı çıktığımız sistem gibi olmamıza izin vermemeliyiz.",
    "Kaybettiğin zaman, dersi kaybetme.",
    "Kayıp değişimden başka bir şey değildir ve değişim Doğanın zevkidir.",
    "Kayıp olduğunu düşündüğün zaman da seni özlüyor.",
    "Kazanma arzusu olmadan herhangi bir savaşa girmek ölümcüldür.",
    "Kazanma arzusundan daha güçlüsü, başlama cesaretidir.",
    "Kazanmak için kazanmayı beklemelisiniz.",
    "Kedilerle oynayacaklar tırmalanmayı beklemeli.",
    "Keep your eyes on the stars and your feet on the ground.",
    "Kelimelerini değiştir. Dünyanı değiştir.",
    "Kendi içinde bölünmüş bir ev ayakta duramaz.",
    "Kendi kahramanın ol, sinema biletinden daha ucuz.",
    "Kendi kurtuluşunuzu yaratın. Başkalarına güvenmeyin.",
    "Kendimizi riske attıkça büyüyoruz. Her yeni deneyim bir risktir.",
    "Kendin ol; diğer herkes zaten alınmış.",
    "Kendin olmana izin vermeyecek bir ilişkiye razı olma.",
    "Kendinden en iyi şekilde yararlan, çünkü senden kalan tek şey bu.",
    "Kendinden memnun olmak ilerlemek için ölümcüldür.",
    "Kendinden ödün verme. Sahip olduğun tek şey sensin.",
    "Kendine güven. Sandığından daha fazlasını biliyorsun.",
    "Kendine güvenmeyen bir adam, başkasına asla gerçekten güvenemez.",
    "Kendine inanmak en iyi ve en güvenli yoldur.",
    "Kendine inanmalısın.",
    "Kendine yapmak istemediğin şeyi başkalarından istemek adil değil.",
    "Kendine yapılmasını istemediğini başkasına yapma.",
    "Kendini bilen aydınlanır.",
    "Kendini bilmek, kendini başka biriyle eylem halinde incelemektir.",
    "Kendini bugüne adayanların hiçbir dünü boşa gitmez.",
    "Kendini ne kadar çok tanırsan, kendini o kadar çok affedersin.",
    "Kendisinin efendisi olmayan hiç kimse özgür değildir.",
    "Kendisiyle uyum içinde yaşayan, dünyayla uyum içinde yaşar.",
    "Keşke mutlu olmaya çalışmaktan vazgeçersek, iyi vakit geçirelim.",
    "Kim olduğumuz asla değişmez. Olduğumuzu sandığımız kişi değişir.",
    "Kim sever, imkansıza inanır.",
    "Kindness is the golden chain by which society is bound together.",
    "Kişi geleceğe geçmişiyle bakar.",
    "Knowledge rests not upon truth alone, but upon error also.",
    "Kolay olanı yöneterek zoru tahmin edin.",
    "Konuşmak pirinç pişirmez.",
    "Korktuğun şeyden çok, bildiğin şeyi dinle.",
    "Korktuğunuz şey, üstesinden gelmek için eylem gerektiren şeydir.",
    "Korku, olumsuzlukların geliştiği bir karanlık odadır.",
    "Korkular bir zihin durumundan başka bir şey değildir.",
    "Kutsal alanınız, kendinizi tekrar tekrar bulabileceğiniz yerdir.",
    "Kötü çelikten yapılmış iyi bir bıçak asla olmadı.",
    "Küskün düşüncelerden kurtulanlar mutlaka huzur bulur.",
    "Küçük başlangıçlardan büyük şeyler doğar.",
    "Küçük fırsatlar genellikle büyük girişimlerin başlangıcıdır.",
    "Küçük meşe palamutlarından güçlü meşeler yetişir.",
    "Küçük şeylere dikkat edin; küçük bir sızıntı büyük bir gemiyi batırır.",
    "Kırışıklıklar sadece gülümsemelerin nerede olduğunu göstermelidir.",
    "Kısa bir söz genellikle çok bilgelik içerir.",
    "Kızgın olmak hiçbir şeyi çözmez.",
    "Learning is finding out what you already know.",
    "Let the beauty of what you love be what you do.",
    "Liderleri beklemeyin, tek başınıza yapın, kişiden kişiye.",
    "Life is a succession of moments. To live each one is to succeed.",
    "Life is really simple, but we insist on making it complicated.",
    "Life is what happens to you while you're busy making other plans.",
    "Life is what happens while you are making other plans.",
    "Logic will get you from A to B. Imagination will take you everywhere.",
    "Love is the master key that opens the gates of happiness.",
    "Make the most of yourself for that is all there is of you.",
    "Makul olanı yapabilir veya neyin mümkün olduğuna karar verebilirsiniz.",
    "Miracles come in moments. Be ready and willing.",
    "Mistakes are always forgivable, if one has the courage to admit them.",
    "Most smiles are started by another smile.",
    "Mucizeden meraka varoluş açılır.",
    "Music in the soul can be heard by the universe.",
    "Mutlu olan başkalarını da mutlu eder.",
    "Mutlu olan zengindir.",
    "Mutlu olmak, korkmadan kendinin farkına varabilmektir.",
    "Mutluluk hazır bir şey değildir. Kendi eylemlerinizden gelir.",
    "Mutluluk kendimize bağlıdır.",
    "Mutluluk sadece sahip olmakta değil, yapmakta bulunur.",
    "Mutluluklarımızı ve acılarımızı, onları yaşamadan çok önce seçeriz.",
    "Mutluluğa giden yol yoktur, yol mutluluktur.",
    "Mutluluğu içinde taşıyan insan için her mevsim güzeldir.",
    "My reputation grows with every failure.",
    "Mücadele yoksa ilerleme de yoktur.",
    "Mükemmellik bir beceri değil, bir tavırdır.",
    "Mükemmellik, sıradan bir şeyi alışılmadık bir şekilde yapmaktır.",
    "Mükemmelliğin bedeli, sorumluluktur.",
    "Mümkün olduğunda nazik ol. Her zaman mümkündür.",
    "Ne kadar az çaba, o kadar hızlı ve güçlü olursunuz.",
    "Ne kadar küçük olursa olsun hiçbir iyilik boşa gitmez.",
    "Ne kadar sert düşersen, o kadar yükseğe zıplarsın.",
    "Ne kadar önemsersen, o kadar güçlü olabilirsin.",
    "Ne olduğumu bıraktığımda, olabileceğim şey olurum.",
    "Ne olduğumuzu biliyoruz ama ne olabileceğimizi bilmiyoruz.",
    "Ne olursa olsun, sorumluluk al.",
    "Ne verirsen onu alırsın.",
    "Neden gizli. Etki herkes tarafından görülebilir.",
    "Nereden geldiğin değil, nereye gittiğin önemlidir.",
    "Neredeyse her şey yoktan var olur.",
    "Nereye giderseniz gidin, tüm kalbinizle gidin.",
    "Nereye gittiğini bilen adama dünya yol verir.",
    "Never, never, never give up.",
    "Neyi düşünüyorsak ona dönüşürüz.",
    "Nezaket, toplumu birbirine bağlayan altın zincirdir.",
    "Neşe en iyi makyajdır.",
    "Neşemizle bağlantı kurmanın önündeki en büyük engel kırgınlıktır.",
    "Niyetimiz gerçekliğimizi yaratır.",
    "No act of kindness, no matter how small, is ever wasted.",
    "No day in which you learn something is a complete loss.",
    "No yesterdays are ever wasted for those who give themselves to today.",
    "Nothing ever goes away until it has taught us what we need to know.",
    "Nothing is a waste of time if you use the experience wisely.",
    "Nothing will work unless you do.",
    "Numberless are the worlds wonders, but none more wonderful than man.",
    "Olabileceklerden uzak dur ve olacaklara bak.",
    "Olabileceğin şey olmak için asla geç değildir.",
    "Olumlu tarafı, potansiyeli görün ve çaba gösterin.",
    "Only those who dare to fail greatly can ever achieve greatly.",
    "Only when we are no longer afraid do we begin to live.",
    "Onu okumasını bilirsen her insan bir cilttir.",
    "Ot nedir? Erdemleri henüz keşfedilmemiş bir bitki.",
    "Otsuz bahçe olmaz.",
    "Our passion is our strength.",
    "Para eksikliğinin eğlenceyi engellemesine asla izin vermeyin.",
    "Parası olan ve zengin olan insanlar vardır.",
    "Parçacıklar düşünebilseydi fiziğin ne kadar zor olacağını bir düşünün.",
    "Peace begins with a smile.",
    "People may doubt what you say, but they will believe what you do.",
    "Performans hırsı aştığında, örtüşmeye başarı denir.",
    "Planlarını kurşun kalemle yaz ve silgiyi Tanrı'ya ver.",
    "Plansız bir hedef sadece bir dilektir.",
    "Rather than wishing for change, you first must be prepared to change.",
    "Real success is finding your lifework in the work that you love.",
    "Reason and free inquiry are the only effectual agents against error.",
    "Refahın yolu yoktur, refah yoludur.",
    "Remember that failure is an event, not a person.",
    "Risk almadan güvenemezsin ama koza içinde de yaşayamazsın.",
    "Rüzgara teslim olursan ona binebilirsin.",
    "Rüzgarlar ve dalgalar her zaman en yetenekli denizcilerin yanındadır.",
    "Rüzgarı yönlendiremeyiz ama yelkenleri ayarlayabiliriz.",
    "Sabır, hikmetin yoldaşıdır.",
    "Sadece izleyerek çok şey gözlemleyebilirsiniz.",
    "Sadece kalbinin sana ne söylediğini yap.",
    "Sadece kendine güven, o zaman nasıl yaşayacağını bileceksin.",
    "Sadece tutunduğun şeyi kaybedersin.",
    "Sahip olduklarımız değil, keyif aldıklarımız bolluğumuzu oluşturur.",
    "Sahip olduğumuz her şey bugünken neden yarın için endişelenelim?",
    "Sahip olmadığın şeylere üzülmek, sahip olduklarını boşa harcamaktır.",
    "Sakin ol   ama al.",
    "Sana ne olduğu değil, ona nasıl tepki verdiğin önemlidir.",
    "Saygı, yıllar içinde değil, eylemlerle kazanılmalıdır.",
    "Sen kendine inanmadıkça kimse sana inanmaz.",
    "Sen özelsin, eşsizsin, en iyisisin!",
    "Seni endişelendiren şey sana hakim olur.",
    "Seni öfkelendiren, seni yener.",
    "Sessiz olamıyorsan zeki ve düşünceli ol.",
    "Sessizlik Sonsuzluk kadar derin, Söz Zaman kadar sığdır.",
    "Sessizlik asla ihanet etmeyen gerçek bir arkadaştır.",
    "Sessizlik asla ihanet etmeyen gerçek dosttur.",
    "Sessizlik büyük bir güç kaynağıdır.",
    "Sessizlik, bilgeliğin etrafındaki bir çittir.",
    "Sevdiğin şeyin güzelliği yaptığın şey olsun.",
    "Sevgi, düşmanı dosta dönüştürebilecek tek güçtür.",
    "Sevip de kaybetmek, hiç sevmemiş olmaktan daha iyidir.",
    "Sevmeyi ancak severek öğrenebiliriz.",
    "Sezgi, düşünen zihne bir sonraki nereye bakacağını söyleyecektir.",
    "Sezgilerimin yoluma öncülük etmesine izin veriyorum.",
    "Sezgilerimize güvenmek çoğu zaman bizi felaketten kurtarır.",
    "Sonbahar, her yaprağın çiçek olduğu ikinci bir bahardır.",
    "Sonsuza dek mutlu yaşamak ancak günden güne mümkündür.",
    "Sonunda hiçbir şey kutsal değildir, ancak kendi zihninizin bütünlüğü.",
    "Sorunlar sadece üzerlerinde dikenler olan fırsatlardır.",
    "Sorunların tarafından itilme, hayallerin tarafından yönetil.",
    "Spring is a time for rebirth and the fulfilment of new life.",
    "Stay away from what might have been and look at what will be.",
    "Success is determined by those whom prove the impossible, possible.",
    "Suya düşerek boğulmazsın. Orada kalarak boğulursun.",
    "Sönmeyen ateşle tutuşturun.",
    "Söylediklerimizi, sözümüzü dinleyenlerden öğreniriz.",
    "Sıkılmış bir yumrukla el sıkışamazsın.",
    "Sıkıntının ilacı meraktır. Merakın tedavisi yoktur.",
    "Sınırlarımızı kabul ettiğimizde, onların ötesine geçiyoruz.",
    "Sınırlarınızı tartışın ve bunların size ait olduğundan emin olun.",
    "Take heed: you do not find what you do not seek.",
    "Take it easy   but take it.",
    "Take rest; a field that has rested gives a bountiful crop.",
    "Talih cesurdan yanadır.",
    "Tam ilgisizlik anları yeni yaratımlar için en iyisidir.",
    "Tanrı her zaman en basit yolu seçer.",
    "Tanrı'nın bizi bu dünyaya sıradan olmamız için koyduğuna inanamıyorum.",
    "Tanrı'yı memnun edecek olan işimizin niceliği değil niteliğidir.",
    "Tarih bana karşı nazik olacak çünkü onu yazmaya niyetliyim.",
    "Tarihten ders alamayanlar onu tekrarlamaya mahkûmdur.",
    "Tecrübe sadece hatalarımıza verdiğimiz isimdir.",
    "Tedbirli nadiren hata yapar.",
    "Tek bir özgürlük biliyorum, o da zihnin özgürlüğüdür.",
    "Tek gerçek hata, kendisinden hiçbir şey öğrenmediğimiz hatadır.",
    "Test edilmek iyidir. Zorlu yaşam en iyi terapist olabilir.",
    "Teşekkür etmek güzel ahlaktan öte bir şeydir. Güzel bir maneviyattır.",
    "The best cure for the body is a quiet mind.",
    "The best place to find a helping hand is at the end of your own arm.",
    "The best thing in every noble dream is the dreamer...",
    "The cure for boredom is curiosity. There is no cure for curiosity.",
    "The deepest craving of human nature is the need to be appreciated.",
    "The difficulties of life are intended to make us better, not bitter.",
    "The energy of the mind is the essence of life.",
    "The future is completely open, and we are writing it moment to moment.",
    "The ladder of success is never crowded at the top.",
    "The less effort, the faster and more powerful you will be.",
    "The more you care, the stronger you can be.",
    "The most formidable weapon against errors of every kind is reason.",
    "The most successful people are those who are good at plan B.",
    "The odds of hitting your target go up dramatically when you aim at it.",
    "The only real failure in life is not to be true to the best one knows.",
    "The only real mistake is the one from which we learn nothing.",
    "The only way to have a friend is to be one.",
    "The time you think you're missing, misses you too.",
    "The truth which has made us free will in the end make us glad also.",
    "The universe is made of stories, not atoms.",
    "The wisest men follow their own direction.",
    "There are no failures   just experiences and your reactions to them.",
    "There are people who have money and people who are rich.",
    "They can do all because they think they can.",
    "Things do not change, we change.",
    "Those that know, do. Those that understand, teach.",
    "Those who cannot learn from history are doomed to repeat it.",
    "Time you enjoyed wasting was not wasted.",
    "To be happy is to be able to become aware of oneself without fright.",
    "To climb steep hills requires a slow pace at first.",
    "To follow, without halt, one aim: There is the secret of success.",
    "To get the full value of joy you must have someone to divide it with.",
    "To hell with circumstances; I create opportunities.",
    "To see things in the seed, that is genius.",
    "Tohum zamanında öğren, hasatta öğret, kışın tadını çıkar.",
    "Tohumdaki şeyleri görmek dehadır.",
    "Tutkumuz gücümüzdür.",
    "Tüm başarılar, kazanılan tüm zenginlikler bir fikirde başlar.",
    "Tüm ciddi cüretler içeriden başlar.",
    "Umudu seçtiğinizde her şey mümkündür.",
    "Uçmak için direncimiz olmalı.",
    "Var olan her şey bir bakıma olacak olanın tohumudur.",
    "Vücut için en iyi tedavi sakin bir zihindir.",
    "We aim above the mark to hit the mark.",
    "We are Divine enough to ask and we are important enough to receive.",
    "We can do no great things, only small things with great love.",
    "We cannot direct the wind but we can adjust the sails.",
    "We know what we are, but know not what we may be.",
    "We lost because we told ourselves we lost.",
    "We must embrace pain and burn it as fuel for our journey.",
    "We never live; we are always in the expectation of living.",
    "We shall never know all the good that a simple smile can do.",
    "Weve got to have a dream if we are going to make a dream come true.",
    "What is a weed? A plant whose virtues have not yet been discovered.",
    "What we see depends mainly on what we look for.",
    "What you are is what you have been. What you ll be is what you do now.",
    "When in doubt, tell the truth.",
    "When there is no enemy within, the enemies outside cannot hurt you.",
    "When you judge another, you do not define them, you define yourself.",
    "When you learn, teach. When you get, give.",
    "Whoever is happy will make others happy, too.",
    "Why worry about tomorrow, when today is all we have?",
    "Worry often gives a small thing a big shadow.",
    "Wrinkles should merely indicate where smiles have been.",
    "Ya sen günü koşarsın ya da gün seni yönetir.",
    "Yalnız olduğun kişiden hoşlanıyorsan, yalnız olamazsın.",
    "Yalnızca artık korkmadığımızda yaşamaya başlarız.",
    "Yalnızca bir şeye inanıyorum, insan iradesinin gücüne.",
    "Yap ya da yapma. Denemek yok.",
    "Yapabileceklerine inananları fethedebilirler.",
    "Yapabileceklerini düşündükleri için her şeyi yapabilirler.",
    "Yapabileceğimiz şeyleri yapsaydık, kendimize hayret ederdik.",
    "Yapabileceğine inanıyorsan yapabilirsin!",
    "Yapamayacağınızı düşündüğünüz şeyleri yapmalısınız.",
    "Yapma becerisi yapmaktan gelir.",
    "Yaptıklarımızı inandığımız için yapıyoruz.",
    "Yaptıkların bir fark yaratıyormuş gibi davran. Fark ediyor.",
    "Yaptıklarından ya da yapacaklarından bahsetme.",
    "Yapılanları asla görmüyorum; sadece yapılması gerekenleri görüyorum.",
    "Yardım eli bulmak için en iyi yer kendi kolunun ucudur.",
    "Yarını bugünden aydınlatın!",
    "Yavaş yürürüm ama asla geriye doğru yürümem.",
    "Yazar olmak istiyorsan yaz.",
    "Yeni bir eylemin üstlenilmesi yeni bir güç getirir.",
    "Yetenek asla ona olan talebi karşılayamaz.",
    "Yetenekli olduğunu düşünen, yeteneklidir.",
    "Yeteneğini kullanabilen dünyadaki tek kişi sensin.",
    "Yokluk, kalbi daha da büyütür.",
    "Yol gökte değildir. Yol gönüldedir.",
    "Yolda bir çatala gelirsen, al.",
    "Yolun kendisi olana kadar yolu geçemezsin.",
    "You always succeed in producing a result.",
    "You are the only person on Earth who can use your ability.",
    "You are the only person on earth who can use your ability.",
    "You can't choose up sides on a round world.",
    "You cannot be lonely if you like the person you're alone with.",
    "You cannot have what you do not want.",
    "You only lose what you cling to.",
    "You really can change the world if you care enough.",
    "You teach best what you most need to learn.",
    "Yuvarlak bir dünyada tarafları seçemezsiniz.",
    "Yuvarlanan taş yosun tutmaz.",
    "Yön değiştirmezseniz, gittiğiniz yere varabilirsiniz.",
    "Yüz kişiyi besleyemiyorsan, sadece birini besle.",
    "Yüzlerce çiçek açsın gönlümüz uyanış bahçesi.",
    "Yüzünü güneşe dön, gölgeler arkandan düşer.",
    "Yıkılmış geçmişle bugünü mahvetme.",
    "Yıllar, günlerin asla bilemeyeceği çok şey öğretir.",
    "Zafer en çok azmedenindir.",
    "Zaman bir insanın harcayabileceği en değerli şeydir.",
    "Zaman en bilge danışmandır.",
    "Zaman harcarken eğlendigin zaman harcama değildir.",
    "Zaman, onu kullanacak herkes için yeterince uzun kalır.",
    "Zaten düşüneceksen büyük düşün.",
    "Zaten düşünmek zorundasın, öyleyse neden büyük düşünmüyorsun?",
    "Zihin her şeydir. Ne olduğunu düşünürsen o olursun.",
    "Zihin paraşüt gibidir. Sadece açıkken çalışırlar.",
    "Zihin uzun zamandır öğrendiğini zorlukla unutur.",
    "Zihnin bizim kabul ettiklerimiz dışında hiçbir sınırı yoktur.",
    "Zorluk sadece iş elbiselerinde fırsattır.",
    "Zorluklar, insana ne olduğunu gösteren şeylerdir.",
    "Zorlukları kabul et, böylece zaferin coşkusunu hissedebilirsin.",
    "Çiçek gibi ol, yüzünü güneşe çevir.",
    "Çiğneyebileceğinden fazlasını ısır, sonra çiğne.",
    "Çok bilgelik genellikle daha az sözcükle gider.",
    "Çok fazla yanlış anlamaktansa biraz anlamak daha iyidir.",
    "Çoğu gülümseme başka bir gülümsemeyle başlar.",
    "Çoğu insan, olmaya karar verdikleri kadar mutludur.",
    "Çoğu insan, olmaya karar verdiği kadar mutludur",
    "Çoğu insan, olmaya karar verdiği kadar mutludur.",
    "Çoğunlukla sözlerimden pişmanlık duyarım ama sessizliğimden asla.",
    "Çözüm basit olduğunda, Tanrı cevap veriyor.",
    "Çünkü yaşayan her şey kutsaldır, yaşam hayattan zevk alır.",
    "Çığdaki hiçbir kar tanesi kendini sorumlu hissetmez.",
    "Öfke için en büyük çare geciktirmektir.",
    "Öfke, enerjinizi üretken bir şey yapmak için kullandığında.",
    "Öfkeyle bir taşa tekme atarsan kendi ayağını incitmiş olursun.",
    "Önce biz hayal etmedikçe hiçbir şey olmaz.",
    "Önce kim olduğunu bil, sonra kendini ona göre süsle.",
    "Önemli ilkeler esnek olmayabilir ve olmalıdır.",
    "Önemli olacak kadar büyük, kazanacak kadar küçük savaşlar seçin.",
    "Örmeye başlayın, ipliği size Allah verecektir.",
    "Özgür insan, düşüncesinin sonuna gitmekten korkmayandır.",
    "Özgürlük, dilediğimiz gibi yaşama hakkıdır.",
    "Özgürlük, sana yapılanlarla yaptıklarındır.",
    "Öğrendiğinde öğret. Aldığında ver.",
    "Öğrenmeden hayal gücü olanın kanatları vardır, ayakları yoktur.",
    "Öğrenmek, sahibini her yerde takip edecek bir hazinedir",
    "Öğrenmek, zaten bildiğini keşfetmektir.",
    "Öğrenmeye en çok ihtiyacın olanı en iyi sen öğretirsin.",
    "Üstün insan konuşmasında alçakgönüllüdür, ancak eylemlerinde aşar.",
    "Üzüntü zamanın kanatlarında uçup gider.",
    "İcra edilmedikçe iyi düşünceler, iyi rüyalardan daha iyi değildir.",
    "İhtiyatlı bir soru, bilgeliğin yarısıdır.",
    "İlgilerinizi sürdürürseniz, her gün bir zafer olabilir.",
    "İlham var, ama bizi çalışırken bulması gerekiyor.",
    "İlişkilerde gerçek sihir, başkalarını yargılamamak demektir.",
    "İmkansızlıklar henüz öğrenmediğimiz şeylerdir.",
    "İnandığında göreceksin.",
    "İnanılan mitler gerçek olma eğilimindedir.",
    "İnce buz üzerinde paten yaparken güvenliğimiz hızımıza bağlıdır.",
    "İnsan doğasının en derin özlemi, takdir edilme ihtiyacıdır.",
    "İnsan kalbinde taşıdığını dünyada da görür.",
    "İnsan nereye dönse, ihtiyacı olan birini bulur.",
    "İnsan yaşadığı yerde değil, sevdiği yerdedir.",
    "İnsanlar hakkında daha az, fikirler hakkında daha fazla meraklı olun.",
    "İnsanların arkasından yürümek için önderlik etmek.",
    "İpin ucuna geldiğinizde bir düğüm atın ve asın.",
    "İrtifanızı yeteneğiniz değil, tavrınız belirler.",
    "İstemediğine sahip olamazsın.",
    "İtibarım her başarısızlıkla birlikte büyüyor.",
    "İyi başlamış, bitirmenin yarısıdır.",
    "İyi bir dinlenme işin yarısıdır.",
    "İyi bir dinleyici ol. Kulakların asla başını belaya sokmaz.",
    "İyi bir karar, sayılara değil, bilgiye dayanır.",
    "İyi seyahat etmek varmaktan daha iyidir.",
    "İyi söylenen bir şey tüm dillerde zekice olur.",
    "İyi sözler demir bir kapının kilidini açar.",
    "İyi yapılmış iyi söylenmişten iyidir.",
    "İyi şans, kararlılığın diğer adıdır.",
    "İyilik en büyük bilgeliktir.",
    "İçgüdülerinizi takip edin. Gerçek bilgelik burada kendini gösterir.",
    "İçinde düşman yokken, dışarıdaki düşmanlar sana zarar veremez.",
    "İçsel olarak elde ettiğimiz şey, dış gerçekliği değiştirecektir.",
    "İşareti vurmak için işaretin yukarısını hedefliyoruz.",
    "İşler değişmez, biz değişiriz.",
    "İşler konuştuğunda, kelimeler bir hiçtir.",
    "İşler ve sözler uyumlu olduğunda, tüm dünya değişir.",
    "Şans cesurların dostudur.",
    "Şans, hazırlığın fırsatla buluştuğunda meydana gelen şeydir.",
    "Şef ol ama asla efendi olma.",
    "Şikayet etmek hiçbir şeyi değiştirmez, sadece önlem almak değiştirir.",
    "Şimdi burada ol. Daha sonra başka bir yerde ol. O kadar karmaşık mı?",
    "Şimdi git. Gelecek kimseye vaat edilmemiştir.",
    "Şu an olduğum kişi olmak için hayatımı verdim. Buna değdi mi?",
    "Şöhret genellikle başka bir şey düşünenlere gelir.",
    "Şükran, ruhtan çıkan en güzel çiçektir.",
    "Şüpheniz olduğunda, gerçeği söyle.",
]